@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: dirac_byte_stream.h,v 1.3 2008/05/02 05:57:18 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: dirac_byte_stream.h,v 1.4 2008/08/14 00:51:08 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -97,10 +97,9 @@ namespace dirac
 
         /**
         * Adds a random access point to the current Dirac byte stream
-        *@param p_accessunit_byteio Access-unit stream. This class is
-        * now responsible for deleting
+        *@param p_seqheader_byteio Sequence header data. 
         */
-        void AddAccessUnit(AccessUnitByteIO *p_accessunit_byteio);
+        void AddSequenceHeader(SequenceHeaderByteIO *p_seqheader_byteio);
 
         /**
         * Adds a picture to the current Dirac byte stream
