@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: common.cpp,v 1.71 2008/05/27 01:29:53 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: common.cpp,v 1.74 2008/08/27 00:17:10 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -131,7 +131,7 @@ void EntropyCorrector::Init()
 
 }
 
-void EntropyCorrector::Update(int bandnum , const PictureParams& pp , 
+void EntropyCorrector::Update(int bandnum , const PictureParams& pp ,
                        CompSort c ,int est_bits , int actual_bits){
     //updates the factors - note that the estimated bits are assumed to already include the correction factor
 
@@ -204,22 +204,7 @@ std::istream & operator>> (std::istream & stream, OLBParams & params)
 
 }
 
-// Codec params functions
-
-CodecParams::CodecParams(const VideoFormat &vd, PictureType ftype, unsigned int num_refs, bool set_defaults):
-    m_x_num_mb(0),
-    m_y_num_mb(0),
-    m_x_num_blocks(0),
-    m_y_num_blocks(0),
-    m_lbparams(3),
-    m_cbparams(3),
-    m_video_format(vd)
-{
-    if (set_defaults)
-        SetDefaultCodecParameters(*this, ftype, num_refs);
-}
-
-void CodecParams::SetBlockSizes(const OLBParams& olbparams , const ChromaFormat cformat)
+void PicturePredParams::SetBlockSizes(const OLBParams& olbparams , const ChromaFormat cformat)
 {
     //given the raw overlapped block parameters, set the modified internal parameters to
     //take account of the chroma sampling format and overlapping requirements, as well
@@ -344,6 +329,16 @@ void CodecParams::SetBlockSizes(const OLBParams& olbparams , const ChromaFormat
     }
 }
 
+
+// Codec params functions
+
+CodecParams::CodecParams(const VideoFormat &vd, PictureType ftype, unsigned int num_refs, bool set_defaults):
+   m_video_format(vd)
+{
+    if (set_defaults)
+        SetDefaultCodecParameters(*this, ftype, num_refs);
+}
+
 WltFilter CodecParams::TransformFilter (unsigned int wf_idx)
 {
     if (wf_idx >= filterNK)
@@ -811,7 +806,6 @@ void SourceParams::SetTransferFunctionIndex (unsigned int tf)
 
 
 //PictureParams functions
-
 // Default constructor
 PictureParams::PictureParams():
     m_psort(PictureSort::IntraRefPictureSort()),
@@ -864,7 +858,6 @@ PictureParams::PictureParams(const ChromaFormat& cf, const PictureSort& ps):
     SetPicSort( ps );
 }
 
-// Constructor
 PictureParams::PictureParams(const SourceParams& sparams):
     m_cformat(sparams.CFormat()),
     m_psort(PictureSort::IntraRefPictureSort()),
@@ -893,33 +886,7 @@ PictureParams::PictureParams(const SourceParams& sparams):
          );
 }
 
-// Constructor
-PictureParams::PictureParams(const SourceParams& sparams, const PictureSort& ps):
-    m_cformat(sparams.CFormat()),
-    m_output(false),
-    m_xl(sparams.Xl()),
-    m_yl(sparams.Yl()),
-    m_using_ac(true)
-{
-    SetPicSort(ps);
 
-    m_cxl = m_cyl = 0;
-    if(m_cformat == format422)
-    {
-        m_cxl = m_xl/2;
-        m_cyl = m_yl;
-    }
-    else if (m_cformat == format420)
-    {
-        m_cxl = m_xl/2;
-        m_cyl = m_yl/2;
-    }
-    else if (m_cformat==format444)
-    {
-        m_cxl = m_xl;
-        m_cyl = m_yl;
-    }
-}
 
 void PictureParams::SetXl(int xlen)
 {
