@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: mot_comp.cpp,v 1.42 2008/04/29 08:51:52 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: mot_comp.cpp,v 1.45 2008/08/27 00:17:10 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -58,39 +58,39 @@ using std::vector;
 
 // Convenience function to perform motion compensation on a picture
 // Static function that motion compensates a picture. It uses the
-// MV precision value in the CodecParams to instantiate the
+// MV precision value in the PicturePredParams to instantiate the
 // appropriate MotionCompensation sub-class.
-void MotionCompensator::CompensatePicture(const CodecParams &cp,
+void MotionCompensator::CompensatePicture(const PicturePredParams &ppp,
                                         const AddOrSub direction ,
-                                        PictureBuffer& buffer ,
-                                        const int pnum,
-                                        const MvData& mv_data )
+                                        const MvData& mv_data,
+                                        Picture* in_pic ,
+					Picture* refsptr[2])
 {
-    switch (cp.MVPrecision())
+    switch (ppp.MVPrecision())
     {
     case MV_PRECISION_EIGHTH_PIXEL:
     {
-        MotionCompensator_EighthPixel my_comp(cp);
-        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
+        MotionCompensator_EighthPixel my_comp(ppp);
+        my_comp.CompensatePicture( direction , mv_data, in_pic, refsptr);
         break;
     }
     case MV_PRECISION_HALF_PIXEL:
     {
-        MotionCompensator_HalfPixel my_comp(cp);
-        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
+        MotionCompensator_HalfPixel my_comp(ppp);
+        my_comp.CompensatePicture( direction , mv_data, in_pic, refsptr);
         break;
     }
     case MV_PRECISION_PIXEL:
     {
-        MotionCompensator_Pixel my_comp(cp);
-        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
+        MotionCompensator_Pixel my_comp(ppp);
+        my_comp.CompensatePicture( direction , mv_data, in_pic, refsptr);
         break;
     }
     case MV_PRECISION_QUARTER_PIXEL:
     default:
     {
-        MotionCompensator_QuarterPixel my_comp(cp);
-        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
+        MotionCompensator_QuarterPixel my_comp(ppp);
+        my_comp.CompensatePicture( direction , mv_data, in_pic, refsptr);
         break;
     }
     }
@@ -102,9 +102,9 @@ void MotionCompensator::CompensatePicture(const CodecParams &cp,
 // Initialises the lookup tables that is needed for motion
 // motion compensation. Creates the necessary arithmetic objects and
 // calls ReConfig to create weighting blocks to fit the values within
-// m_cparams.
-MotionCompensator::MotionCompensator( const CodecParams &cp ):
-    m_cparams(cp),
+// m_predparams.
+MotionCompensator::MotionCompensator( const PicturePredParams &ppp ):
+    m_predparams(ppp),
     luma_or_chroma(true)
 {
     // Allocate for block weights
@@ -129,69 +129,59 @@ MotionCompensator::~MotionCompensator()
 
 //Called to perform motion compensated addition/subtraction on an entire picture.
 void MotionCompensator::CompensatePicture( const AddOrSub direction ,
-                                                    PictureBuffer& my_buffer ,
-                                                    int pnum ,
-                                                    const MvData& mv_data)
+                                         const MvData& mv_data,
+                                        Picture* my_picture ,
+					Picture* refsptr[2])
 {
      m_add_or_sub = direction;
 
-     int ref1_idx,ref2_idx;
-     Picture& my_picture=my_buffer.GetPicture(pnum);
-     const PictureSort& fsort=my_picture.GetPparams().PicSort();
+     const PictureSort& psort=my_picture->GetPparams().PicSort();
 
-     m_cformat = my_picture.GetPparams().CFormat();
+     m_cformat = my_picture->GetPparams().CFormat();
 
-     if (fsort.IsInter())
+     if (psort.IsInter())
      {//we can motion compensate
 
-         const std::vector<int>& refs=my_picture.GetPparams().Refs();
-         if (refs.size()>0)
+         const std::vector<int>& refs=my_picture->GetPparams().Refs();
+
+         // Now check that references are marked correctly
+         if ( !refsptr[0]->GetPparams().PicSort().IsRef() )
          {
-             //extract the references
-             ref1_idx = refs[0];
-             if ( refs.size()>1 )
-                 ref2_idx = refs[1];
-             else
-                 ref2_idx = refs[0];
-
-             const Picture& ref1pic = my_buffer.GetPicture(ref1_idx);
-             const Picture& ref2pic = refs.size() > 0 ? my_buffer.GetPicture(ref2_idx) : ref1pic;
-
-             // Now check that references are marked correctly
-             if ( !ref1pic.GetPparams().PicSort().IsRef() )
-             {
-                 std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref1_idx;
-                 std::cout<<") being used is not marked as a reference. Incorrect output is likely.";
-             }
-             if ( ref1pic.GetPparams().PictureNum() != ref1_idx)
-             {
-                 std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref1_idx;
-                 std::cout<<") not available in buffer. Incorrect output is likely.";
-             }
-
-
-             if ( refs.size()>1 )
-             {
-                 if ( !ref2pic.GetPparams().PicSort().IsRef() )
-                 {
-                     std::cout<<std::endl<<"WARNING! Reference picture (number ";
-                     std::cout<<ref2_idx<<") being used is not marked as a reference. Incorrect output is likely.";
-                 }
-                 if ( ref2pic.GetPparams().PictureNum() != ref2_idx)
-                 {
-                     std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref2_idx;
-                     std::cout<<") not available in buffer. Incorrect output is likely.";
-                 }
-             }
-
-             luma_or_chroma = true;
-             //now do all the components
-             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , Y_COMP);
-
-             luma_or_chroma = false;
-             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , U_COMP);
-             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , V_COMP);
+             std::cout<<std::endl<<"WARNING! Reference picture (number "<<refs[0];
+             std::cout<<") being used is not marked as a reference. Incorrect output is likely.";
          }
+         if ( refsptr[0]->GetPparams().PictureNum() != refs[0] )
+         {
+             std::cout<<std::endl<<"WARNING! Reference picture number 0 ";
+             std::cout<<"does not agree("<<refsptr[0]->GetPparams().PictureNum()<<" and ";
+	     std::cout<<refs[0]<<"). Incorrect output is likely.";
+         }
+
+
+         if ( refs.size()>1 )
+         {
+             if ( !refsptr[1]->GetPparams().PicSort().IsRef() )
+             {
+                 std::cout<<std::endl<<"WARNING! Reference picture (number ";
+                 std::cout<<refs[1]<<") being used is not marked as a reference. Incorrect output is likely.";
+             }
+             if ( refsptr[1]->GetPparams().PictureNum() != refs[1])
+             {
+                 std::cout<<std::endl<<"WARNING! Reference picture number 1 ";
+                 std::cout<<"does not agree("<<refsptr[1]->GetPparams().PictureNum()<<" and ";
+	         std::cout<<refs[1]<<"). Incorrect output is likely.";
+             }
+         }
+	 else
+	     refsptr[1] = refsptr[0];
+
+         luma_or_chroma = true;
+         //now do all the components
+         CompensateComponent( my_picture , refsptr, mv_data , Y_COMP );
+
+         luma_or_chroma = false;
+         CompensateComponent( my_picture  , refsptr, mv_data , U_COMP);
+         CompensateComponent( my_picture  , refsptr, mv_data , V_COMP);
      }
 }
 
@@ -205,16 +195,16 @@ void MotionCompensator::CompensatePicture( const AddOrSub direction ,
 void MotionCompensator::ReConfig()
 {
     if (luma_or_chroma)
-        m_bparams = m_cparams.LumaBParams(2);
+        m_bparams = m_predparams.LumaBParams(2);
     else
-        m_bparams = m_cparams.ChromaBParams(2);
+        m_bparams = m_predparams.ChromaBParams(2);
 
     // Calculate the shift required in horizontal and vertical direction for
     // OBMC and the weighting bits for each reference picture.
 
     // Total shift = shift assuming equal picture weights +
     //               picture weights precision
-    int blocks_per_mb_row = m_cparams.XNumBlocks()/m_cparams.XNumMB();
+    int blocks_per_mb_row = m_predparams.XNumBlocks()/m_predparams.XNumMB();
     int blocks_per_sb_row = blocks_per_mb_row>>1;
     int mb_xlen = m_bparams.Xblen()*blocks_per_mb_row - (m_bparams.Xblen()-m_bparams.Xbsep())*(blocks_per_mb_row-1);
     int mb_ylen = m_bparams.Yblen();
@@ -245,19 +235,18 @@ void MotionCompensator::ReConfig()
     CalculateWeights( sb_xsep, sb_ysep , m_sub_block_weights );
 }
 
-void MotionCompensator::CompensateComponent( Picture& pic ,
-                                                        const Picture &ref1pic ,
-                                                        const Picture& ref2pic ,
-                                                        const MvData& mv_data ,
-                                                        const CompSort cs)
+void MotionCompensator::CompensateComponent( Picture* pic ,
+                                             Picture* refsptr[2] ,
+                                             const MvData& mv_data ,
+                                             const CompSort cs )
 {
     // Set up references to pictures and references
-    PicArray& pic_data_out = pic.Data( cs );
+    PicArray& pic_data_out = pic->Data( cs );
 
     // Size of picture component being motion compensated
 
-    const PicArray& ref1up = ref1pic.UpData( cs );
-    const PicArray& ref2up = ref2pic.UpData( cs );
+    const PicArray& ref1up = refsptr[0]->UpData( cs );
+    const PicArray& ref2up = refsptr[1]->UpData( cs );
 
     // Set up a row of blocks which will contain the MC data, which
     // we'll add or subtract to pic_data_out
@@ -280,11 +269,11 @@ void MotionCompensator::CompensateComponent( Picture& pic ,
         }
     }
 
-    ImageCoords pic_size(pic.GetPparams().Xl(), pic.GetPparams().Yl());
+    ImageCoords pic_size(pic->GetPparams().Xl(), pic->GetPparams().Yl());
     if ( cs != Y_COMP )
     {
-        pic_size.x = pic.GetPparams().ChromaXl();
-        pic_size.y = pic.GetPparams().ChromaYl();
+        pic_size.x = pic->GetPparams().ChromaXl();
+        pic_size.y = pic->GetPparams().ChromaYl();
     }
 
 
@@ -292,7 +281,7 @@ void MotionCompensator::CompensateComponent( Picture& pic ,
     const TwoDArray<ValueType>& dcarray = mv_data.DC( cs );
 
     // Set up references to the vectors
-    const int num_refs = pic.GetPparams().Refs().size();
+    const int num_refs = pic->GetPparams().Refs().size();
     const MvArray* mv_array1;
     const MvArray* mv_array2;
     mv_array1 = &mv_data.Vectors(1);
@@ -321,16 +310,16 @@ void MotionCompensator::CompensateComponent( Picture& pic ,
     const int x_end_data = pic_data_out.FirstX() + std::min(pic_data_out.LengthX(), pic_size.x );
     const int y_end_data = pic_data_out.FirstY() + std::min(pic_data_out.LengthY(), pic_size.y );
 
-    const int blocks_per_mb_row = m_cparams.XNumBlocks()/m_cparams.XNumMB();
+    const int blocks_per_mb_row = m_predparams.XNumBlocks()/m_predparams.XNumMB();
     const int blocks_per_sb_row = blocks_per_mb_row>>1;
 
     // The picture does not contain integral number of blocks. So not all
     // blocks need to be processed. Compute the relevant blocks to be
     // processed 
     int y_num_blocks = std::min((NUM_USED_BLKS(pic_size.y,m_bparams.Ybsep(),m_bparams.Yblen())), 
-                       m_cparams.YNumBlocks());
+                       m_predparams.YNumBlocks());
     int x_num_blocks = std::min((NUM_USED_BLKS(pic_size.x,m_bparams.Xbsep(),m_bparams.Xblen())),  
-                       m_cparams.XNumBlocks());
+                       m_predparams.XNumBlocks());
 
     //Loop over all the block rows
     pos.y = -m_bparams.Yoffset();
@@ -628,10 +617,10 @@ void MotionCompensator::AdjustBlockByRefWeights (
     if (block_mode == INTRA)
         return;
 
-    if (m_cparams.CustomRefWeights())
+    if (m_predparams.CustomRefWeights())
     {
         int ref_wt_prec_bias = 1;
-        for (int i = m_cparams.PictureWeightsBits()-1; i > 0; --i)
+        for (int i = m_predparams.PictureWeightsBits()-1; i > 0; --i)
         {
             ref_wt_prec_bias <<= 1;
         }
@@ -641,8 +630,8 @@ void MotionCompensator::AdjustBlockByRefWeights (
             {
                 for (int x = 0; x < val1_block.LengthX(); ++x)
                 {
-                    val1_block[y][x] *= (m_cparams.Ref1Weight() + 
-                                   m_cparams.Ref2Weight());
+                    val1_block[y][x] *= (m_predparams.Ref1Weight() +
+                                   m_predparams.Ref2Weight());
                 }
             }
         }
@@ -652,8 +641,8 @@ void MotionCompensator::AdjustBlockByRefWeights (
             {
                 for (int x = 0; x < val1_block.LengthX(); ++x)
                 {
-                    val1_block[y][x] *= m_cparams.Ref1Weight();
-                    val2_block[y][x] *= m_cparams.Ref2Weight();
+                    val1_block[y][x] *= m_predparams.Ref1Weight();
+                    val2_block[y][x] *= m_predparams.Ref2Weight();
                     val1_block[y][x] += val2_block[y][x];
                 }
             }
@@ -662,7 +651,7 @@ void MotionCompensator::AdjustBlockByRefWeights (
         {
             for (int x = 0; x < val1_block.LengthX(); ++x)
             {
-                val1_block[y][x] = (val1_block[y][x] + ref_wt_prec_bias) >> m_cparams.PictureWeightsBits();
+                val1_block[y][x] = (val1_block[y][x] + ref_wt_prec_bias) >> m_predparams.PictureWeightsBits();
             }
         }
     }
@@ -841,8 +830,8 @@ void MotionCompensator::FlipY( const TwoDArray<ValueType>& Original ,
 
 // Motion Compesation class that provides pixel precision compensation
 
-MotionCompensator_Pixel::MotionCompensator_Pixel( const CodecParams &cp ) :
-    MotionCompensator( cp )
+MotionCompensator_Pixel::MotionCompensator_Pixel( const PicturePredParams &ppp ) :
+    MotionCompensator( ppp )
 {}
 
 void MotionCompensator_Pixel::BlockPixelPred(
@@ -909,12 +898,12 @@ void MotionCompensator_Pixel::BlockPixelPred(
 
 
 // Motion Compesation class that provides half-pixel precision compensation
-MotionCompensator_HalfPixel::MotionCompensator_HalfPixel( const CodecParams &cp ) :
-    MotionCompensator( cp )
+MotionCompensator_HalfPixel::MotionCompensator_HalfPixel( const PicturePredParams &ppp ) :
+    MotionCompensator( ppp )
 {}
 
 #if !defined (HAVE_MMX)
-void MotionCompensator_HalfPixel::BlockPixelPred( 
+void MotionCompensator_HalfPixel::BlockPixelPred(
                                   TwoDArray<ValueType> &block_data ,
                                   const ImageCoords& pos ,
                                   const ImageCoords& pic_size ,
@@ -925,7 +914,7 @@ void MotionCompensator_HalfPixel::BlockPixelPred(
     const ImageCoords start_pos( std::max(pos.x,0) , std::max(pos.y,0) );
     const ImageCoords ref_start( ( start_pos.x<<1 ) + mv.x ,( start_pos.y<<1 ) + mv.y );
 
-    //An additional stage to make sure the block to be copied does not fall 
+    //An additional stage to make sure the block to be copied does not fall
     //outsidethe reference image.
     const int refXlen = refup_data.LengthX();
     //const int refYlen = refup_data.LengthY();
@@ -968,7 +957,7 @@ void MotionCompensator_HalfPixel::BlockPixelPred(
              y<block_data.LengthY(); ++y, ry+=2 , by=BChk(ry,trueRefYlen))
         {
              for( int x=0 , rx=ref_start.x , bx=BChk(rx,trueRefXlen);
-                  x<block_data.LengthX() ; 
+                  x<block_data.LengthX() ;
                   ++x, ++block_curr, rx+=2 , bx=BChk(rx,trueRefXlen))
              {
                  *block_curr =  refup_data[by][bx];
@@ -979,8 +968,8 @@ void MotionCompensator_HalfPixel::BlockPixelPred(
 #endif
 
 // Motion Compesation class that provides quarter-pixel precision compensation
-MotionCompensator_QuarterPixel::MotionCompensator_QuarterPixel( const CodecParams &cp ) :
-    MotionCompensator( cp )
+MotionCompensator_QuarterPixel::MotionCompensator_QuarterPixel( const PicturePredParams &ppp ) :
+    MotionCompensator( ppp )
 {}
 
 #if !defined (HAVE_MMX)
@@ -1103,8 +1092,8 @@ void MotionCompensator_QuarterPixel::BlockPixelPred(
 
 // Motion Compesation class that provides one eighth-pixel precision
 // compensation
-MotionCompensator_EighthPixel::MotionCompensator_EighthPixel( const CodecParams &cp ) :
-    MotionCompensator( cp )
+MotionCompensator_EighthPixel::MotionCompensator_EighthPixel( const PicturePredParams &ppp ) :
+    MotionCompensator( ppp )
 {}
 
 void MotionCompensator_EighthPixel::BlockPixelPred(
