@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion.cpp,v 1.22 2008/02/01 19:52:30 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: motion.cpp,v 1.27 2008/08/27 00:18:55 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -52,28 +52,15 @@ using namespace std;
 //Motion vector and Motion Estimation structures//
 //////////////////////////////////////////////////
 
-MvData::MvData( const int xnumMB, const int ynumMB , 
-                const int xnumblocks, const int ynumblocks , const int num_refs ):
+MvData::MvData( const PicturePredParams& predparams , const int num_refs ):
+    m_predparams( predparams ),
     m_vectors( Range(1 , num_refs) ),
     m_gm_vectors( Range(1 , num_refs) ),
-    m_modes( ynumblocks , xnumblocks ),
+    m_modes( predparams.YNumBlocks() , predparams.XNumBlocks() ),
     m_dc( 3 ),
-    m_mb_split( ynumMB , xnumMB ),
-    m_gm_params( Range(1 , num_refs) ),
-    m_num_refs(num_refs)
-{
-
-    InitMvData();
-}
-
-MvData::MvData( const int xnumMB , const int ynumMB , const int num_refs ):
-    m_vectors( Range(1 , num_refs) ),
-    m_gm_vectors( Range(1 , num_refs) ),
-    m_modes( 4*ynumMB , 4*xnumMB ),
-    m_dc( 3 ),
-    m_mb_split( ynumMB , xnumMB ),
-    m_gm_params( Range(1 , num_refs) ),
-    m_num_refs(num_refs)
+    m_mb_split( predparams.YNumMB() , predparams.XNumMB() ),
+    m_gm_params( Range(1 , num_refs) )//,
+//    m_num_refs(num_refs)
 {
     InitMvData();
 }
@@ -116,32 +103,19 @@ MvData::~MvData()
 
 
 
-MEData::MEData(const int xnumMB , const int ynumMB ,
-                const int xnumblocks , const int ynumblocks , const int num_refs ):
-     MvData( xnumMB , ynumMB , xnumblocks , ynumblocks , num_refs ),
+MEData::MEData(const PicturePredParams& predparams , const int num_refs ):
+     MvData( predparams , num_refs ),
      m_pred_costs( Range( 1 , num_refs ) ),
-     m_intra_costs( ynumblocks , xnumblocks, 0 ),
-     m_bipred_costs( ynumblocks , xnumblocks ),
-     m_MB_costs( ynumMB , xnumMB ),
-     m_lambda_map( ynumblocks , xnumblocks ),
-     m_inliers( Range( 1 , num_refs ) )
+     m_intra_costs( predparams.YNumBlocks() , predparams.XNumBlocks(), 0 ),
+     m_bipred_costs( predparams.YNumBlocks() , predparams.XNumBlocks() ),
+     m_MB_costs( predparams.YNumMB() , predparams.XNumMB() ),
+     m_lambda_map( predparams.YNumBlocks() , predparams.XNumBlocks() ),
+     m_inliers( Range( 1 , num_refs ) ),
+     m_intra_block_ratio(0.0)
 {
     InitMEData();
 }
 
-MEData::MEData( const int xnumMB , const int ynumMB ,  const int num_refs ):
-     MvData( xnumMB , ynumMB , num_refs ),
-     m_pred_costs( Range( 1 , num_refs ) ),
-     m_intra_costs( 4*ynumMB , 4*xnumMB, 0 ),
-     m_bipred_costs( 4*ynumMB , 4*xnumMB ),
-     m_MB_costs( ynumMB , xnumMB ),
-     m_lambda_map( 4*ynumMB , 4*xnumMB ),
-     m_inliers( Range( 1 , num_refs ) )
-{
-    InitMEData();
-
-}
-
 void MEData::InitMEData()
 {
    // Create the arrays of prediction costs
@@ -358,7 +332,6 @@ void MEData::FindTransitions( TwoDArray<bool>& trans_map , const int ref_num )
          }// i
      }// j
 
-     
 }
 
 
@@ -372,6 +345,35 @@ MEData::~MEData()
         delete m_inliers[i];
 }
 
+void MEData::DropRef( const int rindex ){
+
+    if (rindex==2){}
+    else if (rindex==1){
+       // Swap data for reference 1 and reference 2
+       // so that reference 2 becomes the new reference 1
+
+       MvArray* ptr = m_vectors[1];
+       m_vectors[1] = m_vectors[2];
+       m_vectors[2] = ptr;
+
+       ptr = m_gm_vectors[1];
+       m_gm_vectors[1] = m_gm_vectors[2];
+       m_gm_vectors[2] = ptr;
+
+       OneDArray<float>* ptr2 = m_gm_params[1];
+       m_gm_params[1] = m_gm_params[2];
+       m_gm_params[2] = ptr2;
+
+       TwoDArray<MvCostData>* ptr3 = m_pred_costs[1];
+       m_pred_costs[1] = m_pred_costs[2];
+       m_pred_costs[2] = ptr3;
+
+       TwoDArray<int>* ptr4 = m_inliers[1];
+       m_inliers[1] = m_inliers[2];
+       m_inliers[2] = ptr4;
+    }
+}
+
 namespace dirac
 {
 //! Overloaded operator<< for MvCostData
