@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion.h,v 1.23 2008/03/14 08:17:36 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: motion.h,v 1.29 2008/09/10 12:28:47 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -222,27 +222,20 @@ namespace dirac
         //! Constructor
         /*! 
             Constructor takes:
-            \param  xnumMB  the number of MBs horizontally
-            \param  ynumMB  the number of MBs vertically
-            \param  xnumblocks  the number of blocks horizontally
-            \param  ynumblocks  the number of blocks vertically
-            \param  num_refs  the number of references being used for the picture
+            \param  predparams   Picture prediction parameters
+            \param  num_refs     the number of references being used for the picture
         */
-        MvData( const int xnumMB, const int ynumMB , 
-                const int xnumblocks, const int ynumblocks ,  const int num_refs);
-
-        //! Constructor
-        /*! 
-            Constructor. Numbers of blocks derived from the number of MBs
-            \param  xnumMB  the number of MBs horizontally
-            \param  ynumMB  the number of MBs vertically
-            \param  num_refs  the number of references being used for the picture
-        */
-        MvData( const int xnumMB, const int ynumMB ,  const int num_refs);
+        MvData( const PicturePredParams& predparams ,  const int num_refs);
 
         //! Destructor
         ~MvData();
 
+         //! Return a reference to the local picture prediction params
+        PicturePredParams& GetPicPredParams(){return m_predparams;}
+
+        //! Return a reference to the local picture prediction params
+        const PicturePredParams& GetPicPredParams() const{return m_predparams;}
+
         //! Get the MVs for a reference
         MvArray& Vectors(const int ref_id){return *( m_vectors[ref_id] );}
 
@@ -269,7 +262,7 @@ namespace dirac
 
         //! Get the block prediction modes
         const TwoDArray<PredMode>& Mode() const {return m_modes;}
-     
+
         //! Get the MB split level
         TwoDArray<int>& MBSplit(){return m_mb_split;}
 
@@ -282,10 +275,10 @@ namespace dirac
         //! Get the global motion model parameters
         const OneDArray<float>& GlobalMotionParameters(const int ref_id) const { return *( m_gm_params[ref_id] ); }
 
-        //! Return the number of reference frames
-        unsigned int NumRefs()const {return m_num_refs;}
+    protected:
+        // A local copy of the picture prediction parameters
+	PicturePredParams m_predparams;
 
-    private:
         // Initialises the arrays of data
         void InitMvData();
 
@@ -307,8 +300,8 @@ namespace dirac
         // Global motion model parameters
         OneDArray< OneDArray<float>* > m_gm_params;
 
-        // Number of reference frames
-        const unsigned int m_num_refs;
+//        // Number of reference frames
+//        unsigned int m_num_refs;
     };
 
     //! Class for all the motion estimation data
@@ -324,26 +317,16 @@ namespace dirac
         //! Constructor
         /*! 
             Constructor takes:
-            \param  xnumMB  the number of MBs horizontally
-            \param  ynumMB  the number of MBs vertically
-            \param  xnumblocks  the number of blocks horizontally
-            \param  ynumblocks  the number of blocks vertically
+	        \param predparams the picture prediction parameters
             \param  num_refs  the number of references being used for the picture
         */
-        MEData( const int xnumMB, const int ynumMB , 
-                const int xnumblocks, const int ynumblocks , const int num_refs = 2);
-
-        //! Constructor
-        /*! 
-            Constructor. Numbers of blocks derived from the number of MBs
-            \param  xnumMB  the number of MBs horizontally
-            \param  ynumMB  the number of MBs vertically
-            \param  num_refs  the number of references being used for the picture
-        */
-        MEData( const int xnumMB, const int ynumMB , const int num_refs = 2);
+        MEData( const PicturePredParams& predparams , const int num_refs = 2);
 
         //! Destructor
         ~MEData();
+	
+	//! drop the data relating to one reference
+	void DropRef( int ref_index );
 
         //! Get the block cost structures for each reference
         TwoDArray<MvCostData>& PredCosts(const int ref_id){ return *( m_pred_costs[ref_id] ); }
@@ -369,6 +352,12 @@ namespace dirac
         //! Get the MB costs
         const TwoDArray<float>& MBCosts() const { return m_MB_costs; }
 
+	//! Get the proportion of intra blocks
+	float IntraBlockRatio() const {return m_intra_block_ratio; }
+
+	//! Set the intra block ratio
+	void SetIntraBlockRatio(const float r){ m_intra_block_ratio = r; }
+
         //! Set up the lambda map by detecting motion discontinuities 
         void SetLambdaMap( const int num_refs , const float lambda );
 
@@ -415,6 +404,9 @@ namespace dirac
         // Global motion inliers
         OneDArray< TwoDArray<int>* > m_inliers;
 
+	// Intra block ratio
+	float m_intra_block_ratio;
+
     };
 
     //motion estimation and coding stuff
@@ -444,7 +436,7 @@ namespace dirac
     inline int Norm1(const MVector& mv){//L^1 norm of a motion vector
         return abs(mv.x)+abs(mv.y);
     }
-
+    
     //! Return the mean of a set of unsigned integer values
     unsigned int GetUMean(std::vector<unsigned int>& values);
     
