@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: mv_codec.h,v 1.22 2007/04/11 08:08:49 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: mv_codec.h,v 1.24 2008/08/14 02:30:50 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -120,14 +120,13 @@ namespace dirac
             Creates a MvDataCodec object to encode MV data, based on parameters
             \param    p_byteio   Input/output for the encoded bits
             \param    number_of_contexts the number of contexts used
-         */    
-        PredModeCodec(ByteIO* p_byteio, size_t number_of_contexts);
+            \param    num_refs   Number of references
+         */
+        PredModeCodec(ByteIO* p_byteio, size_t number_of_contexts, const int num_refs);
 
-       
-
-        //! Initialises the contexts    
+        //! Initialises the contexts
         void InitContexts();
-    
+
     private:
 
         // Position of current block
@@ -136,16 +135,18 @@ namespace dirac
         int m_mb_xp, m_mb_yp;
         // Position of top-left block of current MB
         int m_mb_tlb_x, m_mb_tlb_y;
+        // Number of reference pictures
+	int m_num_refs;
 
     private:
 
-        // functions   
+        // functions
         //! Private, bodyless copy constructor: class should not be copied
         PredModeCodec(const PredModeCodec& cpy);
         //! Private, bodyless copy operator=: class should not be assigned
         PredModeCodec& operator=(const PredModeCodec& rhs);
 
-        // coding functions   
+        // coding functions
         // Code the block prediction mode
         void CodeVal(const MvData& in_data);
 
@@ -156,12 +157,11 @@ namespace dirac
         void DoWorkCode( MvData& in_data );
         void DoWorkDecode(MvData& out_data);
 
-        // Context stuff   
+        // Context stuff
         void ResetAll();
 
         //prediction stuff
-        unsigned int Prediction(const TwoDArray<PredMode>& preddata,
-                                const unsigned int num_refs) const;
+        unsigned int Prediction(const TwoDArray<PredMode>& preddata) const;
 
     };
 
