@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: video_format_defaults.cpp,v 1.29 2008/06/03 05:10:12 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: video_format_defaults.cpp,v 1.33 2008/08/27 00:17:11 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -42,9 +42,9 @@
 
 using namespace dirac;
 
-namespace dirac 
+namespace dirac
 {
-void SetDefaultCodecParameters(CodecParams &cparams, 
+void SetDefaultCodecParameters(CodecParams &cparams,
                                PictureType ptype,
                                unsigned int num_refs)
 {
@@ -102,19 +102,20 @@ void SetDefaultCodecParameters(CodecParams &cparams,
     {
         ASSERTM (num_refs > 0 && num_refs < 3, "Number of reference frames should be 1 or 2 fo INTER frames" );
         OLBParams bparams;
-        cparams.SetUsingGlobalMotion(false);
+	PicturePredParams& predparams = cparams.GetPicPredParams();
+        predparams.SetUsingGlobalMotion(false);
         SetDefaultBlockParameters(bparams, cparams.GetVideoFormat());
-        cparams.SetLumaBlockParams(bparams);
-        cparams.SetPictureCodingMode(0);
-        cparams.SetMVPrecision(MV_PRECISION_QUARTER_PIXEL);
+        predparams.SetLumaBlockParams(bparams);
+        predparams.SetMVPrecision(MV_PRECISION_HALF_PIXEL);
         // NOTE: FIXME - need to add global motion params here
-        cparams.SetPictureWeightsPrecision(1);
-        cparams.SetRef1Weight(1);
-        cparams.SetRef2Weight(1);
+        predparams.SetPictureWeightsPrecision(1);
+        predparams.SetRef1Weight(1);
+        predparams.SetRef2Weight(1);
+        cparams.SetPictureCodingMode(0);
     }
 }
 
-void SetDefaultSourceParameters(const VideoFormat &vf, SourceParams& sparams) 
+void SetDefaultSourceParameters(const VideoFormat &vf, SourceParams& sparams)
 {
     std::ostringstream errstr;
     sparams.SetVideoFormat(vf);
@@ -126,7 +127,7 @@ void SetDefaultSourceParameters(const VideoFormat &vf, SourceParams& sparams)
     sparams.SetLeftOffset(0);
     sparams.SetTopOffset(0);
     sparams.SetColourSpecification(1);
-    
+
     switch (vf)
     {
     case VIDEO_FORMAT_CUSTOM:
@@ -287,7 +288,6 @@ void SetDefaultSourceParameters(const VideoFormat &vf, SourceParams& sparams)
         sparams.SetSignalRange(SIGNAL_RANGE_12BIT_VIDEO);
         sparams.SetColourSpecification(4);
         break;
-
     case VIDEO_FORMAT_UHDTV_4K60:
     case VIDEO_FORMAT_UHDTV_4K50:
         sparams.SetXl(3840);
@@ -332,7 +332,7 @@ void SetDefaultSourceParameters(const VideoFormat &vf, SourceParams& sparams)
         sparams.SetCleanHeight(4320);
         sparams.SetColourSpecification(3);
         break;
-    default:
+   default:
         errstr << "Unsupported video format " << sparams.GetVideoFormat()
                << std::endl;
         DIRAC_THROW_EXCEPTION(
@@ -347,7 +347,7 @@ void SetDefaultEncoderParameters(EncoderParams& encparams)
 {
     encparams.SetLossless(false);
     encparams.SetQf(5.5f);
-    encparams.SetMVPrecision(MV_PRECISION_QUARTER_PIXEL);
+    encparams.GetPicPredParams().SetMVPrecision(MV_PRECISION_HALF_PIXEL);
     encparams.SetUsingAC(true);
 
     switch (encparams.GetVideoFormat())
@@ -463,16 +463,16 @@ void SetDefaultBlockParameters(OLBParams& bparams, int pidx)
     {
     case 0: // custom - so undefined values
         return;
-    case 1: 
+    case 1:
         bparams =  OLBParams(8, 8, 4, 4);
         break;
-    case 2: 
+    case 2:
         bparams =  OLBParams(12, 12, 8, 8);
         break;
-    case 3: 
+    case 3:
         bparams =  OLBParams(16, 16, 12, 12);
         break;
-    case 4: 
+    case 4:
         bparams =  OLBParams(24, 24, 16, 16);
         break;
     default:
@@ -499,7 +499,7 @@ unsigned int BlockParametersIndex (const OLBParams& bparams)
         return 3;
     else if (bparams == bparams_4)
         return 4;
-    else 
+    else
         return 0;
 }
 
