@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: wavelet_utils.cpp,v 1.42 2008/05/27 01:29:53 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: wavelet_utils.cpp,v 1.43 2008/08/14 00:51:08 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -149,29 +149,29 @@ void SubbandList::Init(const int depth,const int xlen,const int ylen){
     Subband* tmp;
 
     for (int level = 1; level <= depth; ++level){
-    xl/=2;
-    yl/=2;
-    /* HH */
-    tmp=new Subband( xl , yl , xl , yl , level);
-    AddBand( *tmp );
-    delete tmp;
-
-    /* LH */
-    tmp=new Subband( 0 , yl , xl , yl , level);
-    AddBand( *tmp );
-    delete tmp;
-
-    /* HL */
-    tmp=new Subband(xl , 0 , xl , yl , level);
-    AddBand( *tmp );
-    delete tmp;
-
-    if (level == depth){
-        /* LL */
-        tmp=new Subband( 0 , 0 , xl , yl , level);
+        xl/=2;
+        yl/=2;
+        /* HH */
+        tmp=new Subband( xl , yl , xl , yl , level);
         AddBand( *tmp );
         delete tmp;
-    }
+
+        /* LH */
+        tmp=new Subband( 0 , yl , xl , yl , level);
+        AddBand( *tmp );
+        delete tmp;
+
+        /* HL */
+        tmp=new Subband(xl , 0 , xl , yl , level);
+        AddBand( *tmp );
+        delete tmp;
+
+        if (level == depth){
+            /* LL */
+            tmp=new Subband( 0 , 0 , xl , yl , level);
+            AddBand( *tmp );
+            delete tmp;
+        }
     }
     //now set the parent-child relationships
     int len = bands.size();
@@ -181,104 +181,24 @@ void SubbandList::Init(const int depth,const int xlen,const int ylen){
     (*this)(len-1).SetParent(0);
 
     for (int level = 2; level <= depth; ++level){
-     //do parent-child relationship for other bands
-    (*this)( len-3*(level) ).SetParent( len-3*(level-1) );
-    (*this)(len-3*(level)+1).SetParent(len-3*(level-1)+1);
-    (*this)(len-3*(level)+2).SetParent(len-3*(level-1)+2);
+         //do parent-child relationship for other bands
+        (*this)( len-3*(level) ).SetParent( len-3*(level-1) );
+        (*this)(len-3*(level)+1).SetParent(len-3*(level-1)+1);
+        (*this)(len-3*(level)+2).SetParent(len-3*(level-1)+2);
     }// level
 
 }
 
-//wavelet transform methods
-///////////////////////////
-
-//public methods
-
-WaveletTransform::WaveletTransform(int d, WltFilter f)
-  : m_depth(d),
-    m_filt_sort(f)
+void CoeffArray::SetBandWeights (const EncoderParams& encparams,
+                                 const PictureParams& pparams,
+                                 const CompSort csort)
 {
-    switch( m_filt_sort ){
+    const WltFilter wltfilter = encparams.TransformFilter();
+    const bool field_coding = encparams.FieldCoding();
+    const ChromaFormat cformat = pparams.CFormat();
+    const float cpd = encparams.CPD();
+    const PictureSort psort = pparams.PicSort();
 
-    case DD9_7 :
-        m_vhfilter = new VHFilterDD9_7;
-        break;
-
-    case LEGALL5_3 :
-        m_vhfilter = new VHFilterLEGALL5_3;
-        break;
-
-    case DD13_7 :
-        m_vhfilter = new VHFilterDD13_7;
-        break;
-
-    case HAAR0 :
-        m_vhfilter = new VHFilterHAAR0;
-        break;
-
-    case HAAR1 :
-        m_vhfilter = new VHFilterHAAR1;
-        break;
-
-    default :
-        m_vhfilter = new VHFilterDAUB9_7;
-    }
-}
-
-//! Destructor
-WaveletTransform::~WaveletTransform(){ delete m_vhfilter; }
-
-void WaveletTransform::Transform(const Direction d, PicArray& pic_data, CoeffArray& coeff_data) {
-
-    int xl,yl;
-
-    if (d == FORWARD){
-        xl=coeff_data.LengthX();
-        yl=coeff_data.LengthY();
-
-        // First copy picture data into coeff_data and pad
-        for ( int j=0; j<pic_data.LengthY(); ++j){
-            for ( int i=0; i<pic_data.LengthX(); ++i)
-                coeff_data[j][i] = CoeffType( pic_data[j][i] );
-            for ( int i=pic_data.LengthX(); i<coeff_data.LengthX(); ++i)
-                coeff_data[j][i] = coeff_data[j][pic_data.LastX()];
-        }// j
-        for ( int j=pic_data.LengthY(); j<coeff_data.LengthY(); ++j){
-            for ( int i=0; i<coeff_data.LengthX(); ++i)
-                coeff_data[j][i] = coeff_data[pic_data.LastY()][i];
-        }
-
-        for (int l = 1; l <= m_depth; ++l , xl>>=1 , yl>>=1){
-            m_vhfilter->Split(0,0,xl,yl,coeff_data);
-        }
-
-        m_band_list.Init( m_depth , coeff_data.LengthX() , coeff_data.LengthY() );
-    }
-    else{
-        xl = coeff_data.LengthX()/(1<<(m_depth-1));
-        yl = coeff_data.LengthY()/(1<<(m_depth-1));
-
-        for (int l = 1; l <= m_depth; ++l, xl<<=1 , yl<<=1 )
-            m_vhfilter->Synth(0,0,xl,yl,coeff_data);
-        
-        //band list now inaccurate, so clear
-        m_band_list.Clear();
-
-         // Lastly, copy coeff_data back into picture data
-        for ( int j=0; j<pic_data.LengthY(); ++j){
-            for ( int i=0; i<pic_data.LengthX(); ++i){
-                pic_data[j][i] = ValueType( coeff_data[j][i] );
-            }// i
-        }// j
-    }
-}
-
-void WaveletTransform::SetBandWeights (const float cpd,
-                                       const PictureSort& fsort,
-                                       const ChromaFormat& cformat,
-                                       const CompSort csort,
-                                       const bool field_coding)
-{
     int xlen, ylen, xl, yl, xp, yp;
     float xfreq, yfreq;
     float temp(0.0);
@@ -318,7 +238,7 @@ void WaveletTransform::SetBandWeights (const float cpd,
             xfreq = cpd * ( float(xp) + (float(xl)/2.0) ) / float(xlen);
             yfreq = cpd * ( float(yp) + (float(yl)/2.0) ) / float(ylen);
 
-            if ( fsort.IsInter() )
+            if ( psort.IsInter() )
             {
                 xfreq /= 8.0;
                 yfreq /= 8.0;
@@ -368,31 +288,85 @@ void WaveletTransform::SetBandWeights (const float cpd,
 
     //Finally, adjust to compensate for the absence of scaling in the transform
     //Factor used to compensate:
-    double lfac = m_vhfilter->GetLowFactor();
-    double hfac = m_vhfilter->GetHighFactor();
+    double lfac;
+    double hfac;
+    int filt_shift;
+
+    switch (wltfilter){
+        case DD9_7 :
+            lfac = 1.218660804;;
+            hfac = 0.780720058;
+            filt_shift = 1;
+
+	    break;
+	
+	case LEGALL5_3 :
+            lfac = 1.179535649;
+            hfac = 0.81649658;
+	    filt_shift = 1;
+
+	    break;
+	
+        case DD13_7 :
+            lfac = 1.235705971;
+            hfac = 0.780719354;
+	    filt_shift = 1;
+
+	    break;
+	
+        case HAAR0 : 
+            lfac = 1.414213562;
+            hfac = 0.707106781;
+	    filt_shift = 0;
+ 
+	    break;
+	
+        case HAAR1 : 
+            lfac = 1.414213562;
+            hfac = 0.707106781;
+	    filt_shift = 1;
+
+	    break;
+	
+        case DAUB9_7 :
+            lfac = 1.149604398;
+            hfac = 0.869864452;
+	    filt_shift = 1;
+ 
+	    break;
+	
+        default:
+	    lfac = 1.0;
+	    hfac = 1.0;
+	    filt_shift = 0;
+
+    }
+
 
     int idx;
     int shift;
+    int depth = (m_band_list.Length()-1)/3;
 
     // Do the DC subband
     idx = m_band_list.Length();
-    double cf = (1<<(m_depth*m_vhfilter->GetShift())) / std::pow(lfac,2*m_depth ) ;
+    double cf = (1<<(depth*filt_shift)) / std::pow(lfac,2*depth ) ;
+
     m_band_list(idx).SetWt( m_band_list(idx).Wt()*cf);
 
     // Do the non-DC subbands
-    for (int level=1; level<=m_depth; level++)
+    for (int level=1; level<=depth; level++)
     {
-        shift = (m_depth-level+1)*m_vhfilter->GetShift();
+        shift = (depth-level+1)*filt_shift;
         for ( int orient=3;orient>=1; --orient )
         {
-            idx = 3*(m_depth-level)+orient;
+            idx = 3*(depth-level)+orient;
 
             // index into the subband list
-            idx = 3*(m_depth-level)+orient;
+            idx = 3*(depth-level)+orient;
 
             // Divide through by the weight for the LF subband that was decomposed
             // to create this level
-            cf = 1.0/ std::pow(lfac,2*(m_depth-level) );
+            cf = 1.0/ std::pow(lfac,2*(depth-level) );
 
             if ( m_band_list(idx).Xp() != 0 && m_band_list(idx).Yp() != 0)
                 // HH subband
@@ -411,11 +385,114 @@ void WaveletTransform::SetBandWeights (const float cpd,
 
 }
 
+// Returns a perceptual noise weighting based on extending CCIR 959 values
+// assuming a two-d isotropic response. Also has a fudge factor of 20% for chroma
+float CoeffArray::PerceptualWeight( const float xf ,
+                                     const float yf ,
+                                     const CompSort cs )
+{
+    double freq_sqd( xf*xf + yf*yf );
+
+    if ( cs != Y_COMP )
+        freq_sqd *= 1.2;
+
+    return 0.255 * std::pow( 1.0 + 0.2561*freq_sqd , 0.75) ;
+
+}
+
+
+
+//wavelet transform methods
+///////////////////////////
+
+//public methods
+
+WaveletTransform::WaveletTransform(int d, WltFilter f)
+  : m_depth(d),
+    m_filt_sort(f)
+{
+    switch( m_filt_sort ){
+
+    case DD9_7 :
+        m_vhfilter = new VHFilterDD9_7;
+        break;
+
+    case LEGALL5_3 :
+        m_vhfilter = new VHFilterLEGALL5_3;
+        break;
+
+    case DD13_7 :
+        m_vhfilter = new VHFilterDD13_7;
+        break;
+
+    case HAAR0 :
+        m_vhfilter = new VHFilterHAAR0;
+        break;
+
+    case HAAR1 :
+        m_vhfilter = new VHFilterHAAR1;
+        break;
+
+    default :
+        m_vhfilter = new VHFilterDAUB9_7;
+    }
+}
+
+//! Destructor
+WaveletTransform::~WaveletTransform(){ delete m_vhfilter; }
+
+void WaveletTransform::Transform(const Direction d, PicArray& pic_data, CoeffArray& coeff_data) {
+
+    int xl,yl;
+
+    SubbandList& bands = coeff_data.BandList();
+
+    if (d == FORWARD){
+        xl=coeff_data.LengthX();
+        yl=coeff_data.LengthY();
+
+        // First copy picture data into coeff_data and pad
+        for ( int j=0; j<pic_data.LengthY(); ++j){
+            for ( int i=0; i<pic_data.LengthX(); ++i)
+                coeff_data[j][i] = CoeffType( pic_data[j][i] );
+            for ( int i=pic_data.LengthX(); i<coeff_data.LengthX(); ++i)
+                coeff_data[j][i] = coeff_data[j][pic_data.LastX()];
+        }// j
+        for ( int j=pic_data.LengthY(); j<coeff_data.LengthY(); ++j){
+            for ( int i=0; i<coeff_data.LengthX(); ++i)
+                coeff_data[j][i] = coeff_data[pic_data.LastY()][i];
+        }
+
+        for (int l = 1; l <= m_depth; ++l , xl>>=1 , yl>>=1){
+            m_vhfilter->Split(0,0,xl,yl,coeff_data);
+        }
+
+        bands.Init( m_depth , coeff_data.LengthX() , coeff_data.LengthY() );
+    }
+    else{
+        xl = coeff_data.LengthX()/(1<<(m_depth-1));
+        yl = coeff_data.LengthY()/(1<<(m_depth-1));
+
+        for (int l = 1; l <= m_depth; ++l, xl<<=1 , yl<<=1 )
+            m_vhfilter->Synth(0,0,xl,yl,coeff_data);
+        
+        //band list now inaccurate, so clear
+        bands.Clear();
+
+         // Lastly, copy coeff_data back into picture data
+        for ( int j=0; j<pic_data.LengthY(); ++j){
+            for ( int i=0; i<pic_data.LengthX(); ++i){
+                pic_data[j][i] = ValueType( coeff_data[j][i] );
+            }// i
+        }// j
+    }
+}
+
 // Private functions //
 ///////////////////////
 // NOTEL MMX version is defined in wavelet_utils_mmx.cpp
 // the corresponding changes are made in wavelet_utils_mmx.cpp as well
-void WaveletTransform::VHFilter::Interleave( const int xp ,
+void VHFilter::Interleave( const int xp ,
                                              const int yp ,
                                              const int xl ,
                                              const int yl ,
@@ -450,13 +527,13 @@ void WaveletTransform::VHFilter::Interleave( const int xp ,
 }
 
 #if !defined(HAVE_MMX)
-void WaveletTransform::VHFilter::ShiftRowLeft(CoeffType *row, int length, int shift)
+void VHFilter::ShiftRowLeft(CoeffType *row, int length, int shift)
 {
     for (int i = 0; i < length; ++i)
         row[i] <<= shift;
 }
 
-void WaveletTransform::VHFilter::ShiftRowRight(CoeffType *row, int length, int shift)
+void VHFilter::ShiftRowRight(CoeffType *row, int length, int shift)
 {
     const CoeffType halfway( 1<<(shift-1) );
     for (int i = 0; i < length; ++i)
@@ -464,7 +541,7 @@ void WaveletTransform::VHFilter::ShiftRowRight(CoeffType *row, int length, int s
 }
 #endif
 
-void WaveletTransform::VHFilter::DeInterleave( const int xp ,
+void VHFilter::DeInterleave( const int xp ,
                                                const int yp ,
                                                const int xl ,
                                                const int yl ,
@@ -499,7 +576,7 @@ void WaveletTransform::VHFilter::DeInterleave( const int xp ,
 
 }
 
-void WaveletTransform::VHFilterDAUB9_7::Split (const int xp ,
+void VHFilterDAUB9_7::Split (const int xp ,
                                                const int yp ,
                                                const int xl ,
                                                const int yl ,
@@ -616,7 +693,7 @@ void WaveletTransform::VHFilterDAUB9_7::Split (const int xp ,
 
 }
 
-void WaveletTransform::VHFilterDAUB9_7::Synth (const int xp ,
+void VHFilterDAUB9_7::Synth (const int xp ,
                                                const int yp ,
                                                const int xl ,
                                                const int yl ,
@@ -729,7 +806,7 @@ void WaveletTransform::VHFilterDAUB9_7::Synth (const int xp ,
 #if !defined HAVE_MMX
 // NOTE: MMX version is defined in wavelet_utils_mmx.cpp
 // the corresponding changes are made in wavelet_utils_mmx.cpp as well
-void WaveletTransform::VHFilterLEGALL5_3::Split(const int xp ,
+void VHFilterLEGALL5_3::Split(const int xp ,
                                           const int yp ,
                                           const int xl ,
                                           const int yl ,
@@ -806,7 +883,7 @@ void WaveletTransform::VHFilterLEGALL5_3::Split(const int xp ,
 
 // NOTE: MMX version is defined in wavelet_utils_mmx.cpp
 // the corresponding changes are made in wavelet_utils_mmx.cpp as well
-void WaveletTransform::VHFilterLEGALL5_3::Synth(const int xp ,
+void VHFilterLEGALL5_3::Synth(const int xp ,
                                           const int yp ,
                                           const int xl ,
                                           const int yl ,
@@ -876,7 +953,7 @@ void WaveletTransform::VHFilterLEGALL5_3::Synth(const int xp ,
 }
 #endif
 
-void WaveletTransform::VHFilterDD9_7::Split(const int xp ,
+void VHFilterDD9_7::Split(const int xp ,
                                                 const int yp ,
                                                 const int xl ,
                                                 const int yl ,
@@ -971,7 +1048,7 @@ void WaveletTransform::VHFilterDD9_7::Split(const int xp ,
 #if !defined(HAVE_MMX)
 // NOTE: MMX version is defined in wavelet_utils_mmx.cpp
 // the corresponding changes are made in wavelet_utils_mmx.cpp as well
-void WaveletTransform::VHFilterDD9_7::Synth(const int xp ,
+void VHFilterDD9_7::Synth(const int xp ,
                                                 const int yp ,
                                                 const int xl ,
                                                 const int yl ,
@@ -1060,7 +1137,7 @@ void WaveletTransform::VHFilterDD9_7::Synth(const int xp ,
 }
 #endif
 
-void WaveletTransform::VHFilterDD13_7::Split(const int xp ,
+void VHFilterDD13_7::Split(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1162,7 +1239,7 @@ void WaveletTransform::VHFilterDD13_7::Split(const int xp ,
 #if !defined(HAVE_MMX)
 // NOTE: MMX version is defined in wavelet_utils_mmx.cpp
 // the corresponding changes are made in wavelet_utils_mmx.cpp as well
-void WaveletTransform::VHFilterDD13_7::Synth(const int xp ,
+void VHFilterDD13_7::Synth(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1266,7 +1343,7 @@ void WaveletTransform::VHFilterDD13_7::Synth(const int xp ,
 }
 #endif
 
-void WaveletTransform::VHFilterHAAR0::Split(const int xp ,
+void VHFilterHAAR0::Split(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1304,7 +1381,7 @@ void WaveletTransform::VHFilterHAAR0::Split(const int xp ,
     DeInterleave( xp , yp , xl , yl , coeff_data );
 }
 
-void WaveletTransform::VHFilterHAAR0::Synth(const int xp ,
+void VHFilterHAAR0::Synth(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1337,7 +1414,7 @@ void WaveletTransform::VHFilterHAAR0::Synth(const int xp ,
     }
 }
 
-void WaveletTransform::VHFilterHAAR1::Split(const int xp ,
+void VHFilterHAAR1::Split(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1378,7 +1455,7 @@ void WaveletTransform::VHFilterHAAR1::Split(const int xp ,
     DeInterleave( xp , yp , xl , yl , coeff_data );
 }
 
-void WaveletTransform::VHFilterHAAR1::Synth(const int xp ,
+void VHFilterHAAR1::Synth(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1415,7 +1492,7 @@ void WaveletTransform::VHFilterHAAR1::Synth(const int xp ,
     }
 }
 
-void WaveletTransform::VHFilterHAAR2::Split(const int xp ,
+void VHFilterHAAR2::Split(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1456,7 +1533,7 @@ void WaveletTransform::VHFilterHAAR2::Split(const int xp ,
     DeInterleave( xp , yp , xl , yl , coeff_data );
 }
 
-void WaveletTransform::VHFilterHAAR2::Synth(const int xp ,
+void VHFilterHAAR2::Synth(const int xp ,
                                            const int yp ,
                                            const int xl ,
                                            const int yl ,
@@ -1494,19 +1571,4 @@ void WaveletTransform::VHFilterHAAR2::Synth(const int xp ,
 }
 
 
-// Returns a perceptual noise weighting based on extending CCIR 959 values
-// assuming a two-d isotropic response. Also has a fudge factor of 20% for chroma
-float WaveletTransform::PerceptualWeight( const float xf ,
-                                     const float yf ,
-                                     const CompSort cs )
-{
-    double freq_sqd( xf*xf + yf*yf );
-
-    if ( cs != Y_COMP )
-        freq_sqd *= 1.2;
-
-    return 0.255 * std::pow( 1.0 + 0.2561*freq_sqd , 0.75) ;
-
-}
-
 
