@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: comp_decompress.h,v 1.13 2008/05/07 05:47:00 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: comp_decompress.h,v 1.14 2008/06/19 10:33:24 tjdwave Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -70,9 +70,9 @@ namespace dirac
         /*!
             Decompress a PicArray containing a picture component (Y, U, or V).
 
-            \param  p_component_byteio Bytestream of component data
-            \param  coeff_data    contains the component data to be decompressed
-            \param  bands         the set of all subbands
+            \param p_component_byteio Bytestream of component data
+            \param coeff_data          contains the component data to be decompressed
+            \param bands               the subband metadata 
         */
         void Decompress(ComponentByteIO *p_component_byteio,
                         CoeffArray& coeff_data,
