@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: dirac_parser.cpp,v 1.21 2008/05/02 06:05:04 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: dirac_parser.cpp,v 1.22 2008/06/19 10:33:24 tjdwave Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -305,15 +305,15 @@ static void set_frame_data (const  DiracParser * const parser, dirac_decoder_t *
 
         if (!parser->GetDecoderParams().FieldCoding())
         {
-            set_frame_component (my_picture->Ydata(), Y_COMP, decoder);
-            set_frame_component (my_picture->Udata(), U_COMP, decoder);
-            set_frame_component (my_picture->Vdata(), V_COMP, decoder);
+            set_frame_component (my_picture->Data(Y_COMP), Y_COMP, decoder);
+            set_frame_component (my_picture->Data(U_COMP), U_COMP, decoder);
+            set_frame_component (my_picture->Data(V_COMP), V_COMP, decoder);
         }
         else
         {
-            set_field_component (my_picture->Ydata(), Y_COMP, decoder, pic_num);
-            set_field_component (my_picture->Udata(), U_COMP, decoder, pic_num);
-            set_field_component (my_picture->Vdata(), V_COMP, decoder, pic_num);
+            set_field_component (my_picture->Data(Y_COMP), Y_COMP, decoder, pic_num);
+            set_field_component (my_picture->Data(U_COMP), U_COMP, decoder, pic_num);
+            set_field_component (my_picture->Data(V_COMP), V_COMP, decoder, pic_num);
         }
     }
     return;
