@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: seq_decompress.cpp,v 1.23 2008/05/02 06:05:04 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: seq_decompress.cpp,v 1.25 2008/08/14 00:51:08 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -88,10 +88,9 @@ const PictureParams* SequenceDecompressor::GetNextPictureParams() const
 
 void SequenceDecompressor::NewAccessUnit(ParseUnitByteIO& parseunit_byteio)
 {
-    // read access-unit data
-    AccessUnitByteIO accessunit_byteio(parseunit_byteio,
-                                       m_parse_params, m_srcparams, m_decparams);
-    accessunit_byteio.Input();
+    // read sequence header
+    SequenceHeaderByteIO seqheader_byteio(parseunit_byteio,m_parse_params, m_srcparams, m_decparams);
+    seqheader_byteio.Input();
 
 }
 
@@ -114,7 +113,7 @@ const Picture* SequenceDecompressor::DecompressNextPicture(ParseUnitByteIO* p_pa
         if ( m_pbuffer->IsPictureAvail(m_show_pnum-1) &&
             m_pbuffer->GetPicture(m_show_pnum-1).GetPparams().PicSort().IsNonRef() )
         {
-            m_pbuffer->Clean(m_show_pnum-1);
+            m_pbuffer->Remove(m_show_pnum-1);
             if ( m_decparams.Verbose() )
                 std::cout<<(m_show_pnum-1)<<" ";
         }
