@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: dirac_encoder.cpp,v 1.49 2008/05/27 01:28:27 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: dirac_encoder.cpp,v 1.54 2008/08/27 00:17:11 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -275,7 +275,7 @@ private:
     // encoder parameters
     EncoderParams m_encparams;
     // locally encoded picture in coded order
-    const Picture *m_enc_picture;
+    const EncPicture *m_enc_picture;
     // locally encoded frame ME data
     const MEData *m_enc_medata;
     // locally decoded picture number in display order
@@ -366,8 +366,8 @@ void DiracEncoder::GetInstrumentationData (dirac_encoder_t *encoder)
         instr->refs[i] = pparams.Refs()[i];
 
     // Block separation params
-    instr->ybsep = m_encparams.LumaBParams(2).Ybsep();
-    instr->xbsep = m_encparams.LumaBParams(2).Xbsep();
+    instr->ybsep = m_encparams.GetPicPredParams().LumaBParams(2).Ybsep();
+    instr->xbsep = m_encparams.GetPicPredParams().LumaBParams(2).Xbsep();
 
     // Num macroblocks
     instr->mb_ylen = m_enc_medata->MBSplit().LengthY();
@@ -469,6 +469,11 @@ void DiracEncoder::SetSourceParams (const dirac_encoder_context_t *enc_ctx)
     m_srcparams.SetXl( enc_ctx->src_params.width );
     m_srcparams.SetYl( enc_ctx->src_params.height );
 
+    m_srcparams.SetCleanWidth( m_srcparams.Xl() );
+    m_srcparams.SetCleanHeight( m_srcparams.Yl() );
+    m_srcparams.SetLeftOffset( 0 );
+    m_srcparams.SetTopOffset( 0 );
+
     m_srcparams.SetSourceSampling( enc_ctx->src_params.source_sampling );
     if (m_srcparams.FrameRate().m_num != (unsigned int)enc_ctx->src_params.frame_rate.numerator ||
         m_srcparams.FrameRate().m_denom != (unsigned int)enc_ctx->src_params.frame_rate.denominator)
@@ -542,7 +547,7 @@ void DiracEncoder::SetEncoderParams (const dirac_encoder_context_t *enc_ctx)
                              enc_ctx->enc_params.prefilter_strength);
     m_encparams.SetUFactor(1.5f);
     m_encparams.SetVFactor(0.75f);
-    m_encparams.SetMVPrecision(enc_ctx->enc_params.mv_precision);
+    m_encparams.GetPicPredParams().SetMVPrecision(enc_ctx->enc_params.mv_precision);
     m_encparams.SetUsingAC(enc_ctx->enc_params.using_ac);
     bparams.SetYblen( enc_ctx->enc_params.yblen );
     bparams.SetXblen( enc_ctx->enc_params.xblen );
@@ -561,7 +566,7 @@ void DiracEncoder::SetEncoderParams (const dirac_encoder_context_t *enc_ctx)
         //have I-frame only coding
         m_encparams.SetL1Sep(0);
     }
-    m_encparams.SetBlockSizes( bparams , enc_ctx->src_params.chroma );
+    m_encparams.GetPicPredParams().SetBlockSizes( bparams , enc_ctx->src_params.chroma );
 
     // Set transforms parameters
     m_encparams.SetIntraTransformFilter(enc_ctx->enc_params.intra_wlt_filter);
@@ -595,17 +600,19 @@ int DiracEncoder::CompressNextPicture ()
     if (!m_num_loaded_pictures)
         return 0;
 
-    const Picture *mypicture = m_seqcomp->CompressNextPicture();
+    const EncPicture *mypicture = m_seqcomp->CompressNextPicture();
 
-       m_decpnum = -1;
-    if (mypicture)
-    {
+    m_decpnum = -1;
+
+    if (mypicture){
         m_enc_picture = m_seqcomp->GetPictureEncoded();
-        m_enc_medata = m_seqcomp->GetMEData();
+	if (m_enc_picture->GetPparams().PicSort().IsIntra()==false)
+            m_enc_medata = &m_enc_picture->GetMEData();
+	else
+	    m_enc_medata = NULL;
 
         if (m_return_decoded_pictures &&
-            mypicture->GetPparams().PictureNum() != m_show_pnum)
-        {
+                mypicture->GetPparams().PictureNum() != m_show_pnum){
             int ret_val;
             m_show_pnum = mypicture->GetPparams().PictureNum();
             TEST (! (m_return_decoded_pictures && !m_dec_buf) );
@@ -623,8 +630,7 @@ int DiracEncoder::CompressNextPicture ()
             }
         }
     }
-    else
-    {
+    else{
         m_enc_picture = NULL;
         m_enc_medata = NULL;
     }
@@ -632,12 +638,11 @@ int DiracEncoder::CompressNextPicture ()
     if(!m_dirac_byte_stream.IsUnitAvailable())
         return 0;
 
-    if (mypicture)
-    {
+    if (mypicture){
          m_num_coded_pictures++;
-           TESTM (m_enc_picture != 0, "Encoder picture available");
+         TESTM (m_enc_picture != 0, "Encoder picture available");
     }
-       return 1;
+    return 1;
 }
 
 void DiracEncoder::GetPictureStats(dirac_encoder_t *encoder)
@@ -977,7 +982,7 @@ static void SetEncoderParameters(dirac_encoder_context_t *enc_ctx,
     encparams.ybsep = default_block_params.Ybsep();
 
     // set default MV parameters
-    encparams.mv_precision = default_enc_params.MVPrecision();
+    encparams.mv_precision = default_enc_params.GetPicPredParams().MVPrecision();
 
     // by default, use hierarchical, not full search
     encparams.full_search = 0;
