@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: rate_control.cpp,v 1.23 2008/06/03 09:57:13 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: rate_control.cpp,v 1.31 2008/09/03 00:33:59 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -93,7 +93,7 @@ RateController::RateController(int trate, SourceParams& srcp, EncoderParams& enc
     m_I_qf (encp.Qf()),
     m_I_qf_long_term(encp.Qf()),
     m_target_rate(trate),
-    m_buffer_size(4000*trate),// for the moment, set buffer size to 4*bitrate
+    m_buffer_size(5000*trate),// for the moment, set buffer size to 5 seconds
     m_buffer_bits((m_buffer_size*9)/10),// initial occupancy of 90%
     m_encparams(encp),
     m_fcount(encp.L1Sep() ),
@@ -102,16 +102,20 @@ RateController::RateController(int trate, SourceParams& srcp, EncoderParams& enc
 {
     SetFrameDistribution();
     CalcTotalBits(srcp);
-    
+
     if (m_intra_only)
         m_Iframe_bits = m_total_GOP_bits;
     else
     {
         m_Iframe_bits = m_total_GOP_bits/10;
         m_L1frame_bits = (m_Iframe_bits*3)/m_num_L1frame;
-        m_L2frame_bits = ( m_total_GOP_bits - m_Iframe_bits - 
-                           m_L1frame_bits*m_num_L1frame )/
-                     (m_encparams.GOPLength()-1-m_num_L1frame);
+	if (m_encparams.L1Sep()>1)
+            m_L2frame_bits = ( m_total_GOP_bits - m_Iframe_bits -
+                               m_L1frame_bits*m_num_L1frame )/
+                         (m_encparams.GOPLength()-1-m_num_L1frame);
+	else
+	    m_L2frame_bits = 0;
+
     }
 }
 
@@ -149,7 +153,7 @@ void RateController::CalcTotalBits(const SourceParams& sourceparams)
 
         std::cout<<"GOP Length = "<<GOP_length<< std::endl;
 
-        std::cout<<"Picture Rate = "<<f_rate<< std::endl;
+        std::cout<<"Frame Rate = "<<f_rate<< std::endl;
 
         std::cout<<"GOP Duration = "<<m_GOP_duration<< std::endl;
 
@@ -187,16 +191,36 @@ double RateController::ProjectedSubgroupRate()
 
     return (double)(bits)/(1000.0*m_GOP_duration);
 }
-void RateController::CalcNextQualFactor(const PictureParams& fparams, int num_bits)
+void RateController::CalcNextQualFactor(const PictureParams& pparams, int num_bits)
 {
 
     // Decrement the subgroup frame counter. This is zero just after the last
     // L2 frame before the next L1 frame i.e. before the start of an L1L2L2
     // subgroup
     m_fcount--;
-
     UpdateBuffer( num_bits );
-    
+
+    // filter tap for adjusting the QF
+    double target_ratio = 0.9;
+
+    int field_factor = m_encparams.FieldCoding() ? 2 : 1;
+
+    double top_size = (1.0 - target_ratio)-0.5;
+    double bottom_size = target_ratio-0.1;
+    double actual_ratio = double(m_buffer_bits)/double(m_buffer_size);
+    double tap;
+
+    if ((pparams.PictureNum()/field_factor)<=3*m_encparams.L1Sep() )
+        tap = 1.0;
+    else{
+        if (actual_ratio>target_ratio)
+            tap = (actual_ratio-target_ratio)/top_size;
+        else
+            tap = (target_ratio-actual_ratio)/bottom_size;
+
+        tap = std::min( 1.0, std::max(tap, 0.25 ));
+    }
+
 
     if (!m_intra_only)
     {
@@ -205,26 +229,22 @@ void RateController::CalcNextQualFactor(const PictureParams& fparams, int num_bi
 
         // First, do normal coding
 
-        if ( fparams.PictureNum() % m_encparams.GOPLength()==0 )
+        if ( pparams.PicSort().IsIntra() == true )
         {
-            // We have a scheduled I frame
             target = m_Iframe_bits;
 
             if (num_bits < target/2 )
-            {
                 emergency_realloc = true;
-            }
-    
-            
+
             // Update the statistics
             m_frame_complexity.SetIComplexity( num_bits );
 
             // We've just coded an intra frame so we need to set qf for
             // the next group of L2(B) frames
+	    m_qf = std::max(tap*m_qf+(1.0-tap)*m_encparams.Qf(), m_encparams.Qf()-1.0);
             m_encparams.SetQf( m_qf );
 
-            if (fparams.PictureNum()==0 ||
-               (m_encparams.FieldCoding() && fparams.PictureNum() < 2))
+            if (pparams.PictureNum()/field_factor==0)
             {
                 // We've just coded the very first frame, which is a special
                 // case as the two L2 frames which normally follow are missing
@@ -232,47 +252,38 @@ void RateController::CalcNextQualFactor(const PictureParams& fparams, int num_bi
             }
 
         }
-        else
+
+        //Update complexities
+        if ( (pparams.PictureNum()/field_factor) % m_encparams.L1Sep() !=0 )
         {
-            // We have a scheduled inter frame (we may have an inserted
-            // intra frame). We allocate bits for the next
-            // group if we can (L1 frame) or if we need to (emergency).
+            // Scheduled B/L2 picture
 
-            //Update complexities
-            if ( fparams.PictureNum() % m_encparams.L1Sep() !=0 )
-            {
-                // Scheduled B/L2 picture 
-                
-                target = m_L2frame_bits;
+            target = m_L2frame_bits;
 
-                if (num_bits < target/2 ){
-                    emergency_realloc = true;
-                }
-
-                m_L2_complexity_sum += num_bits;
-            }
-            else
-            {
-                // Scheduled P/L1 picture 
-
-                target = m_L1frame_bits;
- 
-                if (num_bits < target/2 ){
-                    emergency_realloc = true; 
-                }
-                    
-                m_frame_complexity.SetL1Complexity(num_bits);
+            if (num_bits < target/2 ){
+                emergency_realloc = true;
             }
 
+            m_L2_complexity_sum += num_bits;
+        }
+        else if ( pparams.PicSort().IsIntra() == false )
+        {
+            // Scheduled P/L1 picture (if inserted I picture, don't change the complexity)
+
+            target = m_L1frame_bits;
+
+            if (num_bits < target/2 ){
+                emergency_realloc = true;
+            }
+
+            m_frame_complexity.SetL1Complexity(num_bits);
         }
-        
 
         if ( m_fcount==0 || emergency_realloc==true)
         {
-
             if (emergency_realloc==true && m_encparams.Verbose()==true )
                 std::cout<<std::endl<<"Major undershoot of frame bit rate: re-allocating";
-            
+
 
             /* We recompute allocations for the next subgroup */
 
@@ -281,7 +292,7 @@ void RateController::CalcNextQualFactor(const PictureParams& fparams, int num_bi
                 m_frame_complexity.SetL2Complexity(m_L2_complexity_sum/
                                                   (m_encparams.L1Sep()-1-m_fcount));
             }
-            Allocate(fparams.PictureNum());
+            Allocate( (pparams.PictureNum()/field_factor) );
 
             /* We work out what this means for the quality factor and set it*/
 
@@ -293,17 +304,30 @@ void RateController::CalcNextQualFactor(const PictureParams& fparams, int num_bi
             // from measured values (complexities)
             double prate = ProjectedSubgroupRate();
 
-            if (emergency_realloc==true && m_encparams.Verbose()==true )
-            {
+//            if (emergency_realloc==true && m_encparams.Verbose()==true )
+//            {
                 std::cout<<std::endl<<"Target subgroup rate = "<<trate;
                 std::cout<<", projected subgroup rate = "<<prate;
-            }
+//            }
             // Determine K value
             double K = std::pow(prate, 2)*std::pow(10.0, ((double)2/5*(10-m_qf)))/16;
 
             // Determine a new QF
-            m_qf = 10 - (double)5/2*log10(16*K/std::pow(trate, 2));
+            double new_qf = 10 - (double)5/2*log10(16*K/std::pow(trate, 2));
+	    if ( ( std::abs(m_qf-new_qf)<0.25 && new_qf > 4.0 ) || new_qf>8.0)
+	        m_qf = new_qf;
+	    else
+	        m_qf = tap*new_qf+(1.0-tap)*m_qf;
+
             m_qf = ReviewQualityFactor( m_qf , num_bits );
+
+            if ( m_qf<8.0 ){
+                if (prate<2*trate)
+                    m_qf = std::max(m_qf,m_encparams.Qf()-1.0);
+	        else
+                    m_qf = std::max(m_qf,m_encparams.Qf()-2.0);
+            }
+
             m_encparams.SetQf(m_qf);
 
 
@@ -421,10 +445,10 @@ void RateController::Allocate (const int fnum)
     if ( !m_intra_only)
     {
         double correction;
-        if (buffer_occ<0.9 && ( (fnum+1) % m_encparams.GOPLength())==0 )
+        if (buffer_occ<0.9 && ( (fnum+1) % 4*m_encparams.L1Sep())==0 )
         {            
             // If we're undershooting buffer target, correct slowly
-            correction = std::min( 0.1, 0.1*(0.9 - buffer_occ )/0.9 );
+            correction = std::min( 0.25, 0.25*(0.9 - buffer_occ )/0.9 );
             m_GOP_target = ( long int)(double(m_total_GOP_bits)*( 1.0-correction) );   
         }    
         else if (buffer_occ>0.9 && ((fnum+1) % m_encparams.L1Sep())==0)
@@ -483,7 +507,7 @@ float RateController::ClipQualityFactor( const float qfac )
 {
     // Keep the quality factor in a sensible range
     if ( !m_intra_only )
-        return std::min( std::max(qfac, 0.0f) , 16.0f );
+        return std::min( std::max(qfac, 0.0f), 16.0f);
     else
         return std::max(qfac, 0.0f);
 }
