@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: seq_compress.h,v 1.24 2008/06/03 09:57:13 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: seq_compress.h,v 1.31 2008/08/27 00:17:11 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -49,7 +49,7 @@
 
 #include <libdirac_byteio/dirac_byte_stream.h>
 #include <libdirac_common/common.h>
-#include <libdirac_common/picture_buffer.h>
+#include <libdirac_encoder/enc_queue.h>
 #include <libdirac_common/pic_io.h>
 #include <libdirac_common/dirac_assertions.h>
 #include <libdirac_encoder/quality_monitor.h>
@@ -122,13 +122,13 @@ namespace dirac
 
             \return           pointer to the next locally decoded picture available for display
         */
-        const Picture *CompressNextPicture();
+        const EncPicture *CompressNextPicture();
+
+        //! Set up the appropriate prediction parameters for a picture
+        virtual void SetPicTypeAndRefs( PictureParams& pparams ) = 0;
 
         //! Return a pointer to the most recent picture encoded
-        const Picture *GetPictureEncoded();
-
-        //! Return Motion estimation info related to the most recent picture encoded
-        const MEData *GetMEData();
+        const EncPicture *GetPictureEncoded();
 
         DiracByteStats EndSequence();
 
@@ -145,6 +145,9 @@ namespace dirac
 
     protected:
 
+        //! Set up the motion block parameters
+        void SetMotionParameters();
+
         //! Uses the GOP parameters to convert picture numbers in coded order to display order.
         /*!
              Uses the GOP parameters to convert picture numbers in coded order
@@ -157,18 +160,16 @@ namespace dirac
         //! Make a report to screen on the coding results for the whole sequence
         void MakeSequenceReport();
 
-        //! Return original un-encoded picture
-        virtual const Picture& OriginalPicture(int picture_num)
-        { return m_mebuffer->GetPicture(picture_num); }
-
         //! Remove unwanted pictures from picture buffers
         virtual void CleanBuffers();
 
-        //! Return true if we need to start a new access unit. Purely virtual. The child class will have to define it.
-        virtual bool IsNewAccessUnit() = 0;
+        //! Update the CBR model based on the data we've compressed.
+	//Purely virtual. The child class will have to define it.
+        virtual void UpdateCBRModel(EncPicture& my_picture, const PictureByteIO* picture_byteio) = 0;
+
+        //! Update the parameters to be used in advance of coding an intra frame
+        void UpdateIntraPicCBRModel( const PictureParams& , const bool is_a_cut );
 
-        //! Compress the picture using constant bit rate coding. Purely virtual. The child class will have to define it.
-        virtual void RateControlCompress(Picture& my_picture, bool is_a_cut) = 0;
         //! Returns true if the encoder can encode a picture
         bool CanEncode();
 
@@ -183,25 +184,38 @@ namespace dirac
         */
         bool m_just_finished;
 
+        //! A class to hold the basic block parameters
+        OLBParams m_basic_olb_params0;
+
+        //! A class to hold the basic block parameters
+        OLBParams m_basic_olb_params1;
+
+        //! A class to hold the basic block parameters
+        OLBParams m_basic_olb_params2;
+
+        //! A class to hold block parameters to use when there are lots of intra blocks
+        OLBParams* m_intra_olbp;
+
         //! The parameters of the input source
         SourceParams& m_srcparams;
 
         //! The parameters used for encoding.
         EncoderParams& m_encparams;
 
-        //! A class to hold the basic block parameters
-        OLBParams m_basic_olb_params0;
-        OLBParams m_basic_olb_params1;
-        OLBParams m_basic_olb_params2;
+        //! The parameters used for ME/MC
+        PicturePredParams& m_predparams;
+
+	//! The L1 separation currently in use
+	int m_L1_sep;
+
+        //! Generic picture parameters for initialising pictures
+        PictureParams m_pparams;
 
         //! Pointer pointing at the picture input.
         StreamPicInput* m_pic_in;
 
         //! A picture buffer used for local storage of pictures whilst pending re-ordering or being used for reference.
-        PictureBuffer* m_fbuffer;
-
-        //! A picture buffer for motion estimation
-        PictureBuffer* m_mebuffer;
+        EncQueue m_enc_pbuffer;
 
         //state variables for CompressNextPicture
 
@@ -217,6 +231,9 @@ namespace dirac
         //! The index, in display order, of the last picture read
         int m_last_picture_read;
 
+	//! The picture number of the last GOP start
+	int m_gop_start_num;
+
         //! A delay so that we don't display what we haven't coded
         int m_delay;
 
@@ -235,9 +252,6 @@ namespace dirac
         //! Flag to check if End of Sequence has been signalled by the end user
         bool m_eos_signalled;
 
-        //! Picture number where previous GOP started
-        int m_prev_gop_start;
-
     private:
         //! Copy constructor is private and body-less
         /*!
@@ -294,10 +308,13 @@ namespace dirac
                                 false - otherwise
         */
         virtual bool LoadNextFrame();
-    protected:
+        
+        //! Set up the appropriate prediction parameters for a picture
+        virtual void SetPicTypeAndRefs( PictureParams& pparams );
+
+protected:
         virtual int CodedToDisplay(const int pnum);
-        virtual bool IsNewAccessUnit();
-        virtual void RateControlCompress(Picture& my_picture, bool is_a_cut);
+        virtual void UpdateCBRModel(EncPicture& my_picture, const PictureByteIO* picture_byteio);
 
     };
 
@@ -332,7 +349,7 @@ namespace dirac
 
         //! Load data
         /*!
-            Load oen frame i.e. two fields of data into the Sequence
+            Load one frame i.e. two fields of data into the Sequence
             Compressor. Sets m_all_done to true if no more data is available
             to be loaded.
             \return             true - if both fields load succeeded.
@@ -340,15 +357,15 @@ namespace dirac
         */
         virtual bool LoadNextFrame();
 
-    protected:
-        virtual const Picture& OriginalPicture(int picture_num);
+        
+        //! Set up the appropriate prediction parameters for a picture
+        virtual void SetPicTypeAndRefs( PictureParams& pparams );
 
-        virtual void CleanBuffers();
+    protected:
 
         virtual int CodedToDisplay(const int pnum);
-        virtual bool IsNewAccessUnit();
 
-        virtual void RateControlCompress(Picture& my_picture, bool is_a_cut);
+        virtual void UpdateCBRModel(EncPicture& my_picture, const PictureByteIO* picture_byteio);
     private:
         //! Filter fields
         /*!
@@ -357,9 +374,6 @@ namespace dirac
         */
         void PreMotionEstmationFilter (PicArray& comp);
 
-        //! A picture buffer for original pictures
-        PictureBuffer* m_origbuffer;
-
         // Field1 bytes
         int m_field1_bytes;
         // Field2 bytes
