@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_mode_decn.cpp,v 1.26 2008/01/31 11:25:19 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: me_mode_decn.cpp,v 1.32 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -37,33 +37,33 @@
 * ***** END LICENSE BLOCK ***** */
 
 #include <libdirac_motionest/me_mode_decn.h>
-#include <libdirac_common/picture_buffer.h>
+#include <libdirac_encoder/enc_queue.h>
 using namespace dirac;
 
 #include <algorithm>
 
 using std::vector;
 
-ModeDecider::ModeDecider( const EncoderParams& encp):
-    m_encparams( encp ),
+ModeDecider::ModeDecider( const PicturePredParams& ppp):
+    m_predparams( ppp ),
     m_level_factor(3),
     m_mode_factor(3),
     m_me_data_set(3)
 {
 
-    // The following factors normalise costs for sub-MBs and MBs to those of 
+    // The following factors normalise costs for sub-MBs and MBs to those of
     // blocks, so that the overlap is take into account (e.g. a sub-MB has
-    // length XBLEN+XBSEP and YBLEN+YBSEP). The MB costs for a 1x1 
+    // length XBLEN+XBSEP and YBLEN+YBSEP). The MB costs for a 1x1
     // decomposition are not directly comprable to those for other decompositions
     // because of the block overlaps. These factors remove these effects, so that
     // all SAD costs are normalised to the area corresponding to non-overlapping
-    // 16 blocks of size XBLEN*YBLEN.    
+    // 16 blocks of size XBLEN*YBLEN.
 
-   m_level_factor[0] = float( 16 * m_encparams.LumaBParams(2).Xblen() * m_encparams.LumaBParams(2).Yblen() )/
-       float( m_encparams.LumaBParams(0).Xblen() * m_encparams.LumaBParams(0).Yblen() );
+   m_level_factor[0] = float( 16 * m_predparams.LumaBParams(2).Xblen() * m_predparams.LumaBParams(2).Yblen() )/
+       float( m_predparams.LumaBParams(0).Xblen() * m_predparams.LumaBParams(0).Yblen() );
 
-   m_level_factor[1] = float( 4 * m_encparams.LumaBParams(2).Xblen() * m_encparams.LumaBParams(2).Yblen() )/
-       float( m_encparams.LumaBParams(1).Xblen() * m_encparams.LumaBParams(1).Yblen() );
+   m_level_factor[1] = float( 4 * m_predparams.LumaBParams(2).Xblen() * m_predparams.LumaBParams(2).Yblen() )/
+       float( m_predparams.LumaBParams(1).Xblen() * m_predparams.LumaBParams(1).Yblen() );
 
    m_level_factor[2] = 1.0f;
 
@@ -74,17 +74,17 @@ ModeDecider::ModeDecider( const EncoderParams& encp):
 
 ModeDecider::~ModeDecider()
 {
-    if (fsort.IsInter())
+    if (m_psort.IsInter())
     {
         delete m_me_data_set[0];
         delete m_me_data_set[1];
     }
 }
 
-void ModeDecider::DoModeDecn(const PictureBuffer& my_buffer, int frame_num, MEData& me_data)
+void ModeDecider::DoModeDecn( EncQueue& my_buffer, int pic_num )
 {
 
-     // We've got 'raw' block motion vectors for up to two reference frames. Now we want
+     // We've got 'raw' block motion vectors for up to two reference pictures. Now we want
      // to make a decision as to mode. In this initial implementation, this is bottom-up
     // i.e. find mvs for MBs and sub-MBs and see whether it's worthwhile merging.    
 
@@ -93,43 +93,48 @@ void ModeDecider::DoModeDecn(const PictureBuffer& my_buffer, int frame_num, MEDa
     // Initialise // 
     ////////////////
 
-    fsort = my_buffer.GetPicture(frame_num).GetPparams().PicSort();
-    if (fsort.IsInter())
+    m_psort = my_buffer.GetPicture(pic_num).GetPparams().PicSort();
+    if (m_psort.IsInter())
     {
         // Extract the references
-        const vector<int>& refs = my_buffer.GetPicture(frame_num).GetPparams().Refs();
+        const vector<int>& refs = my_buffer.GetPicture(pic_num).GetPparams().Refs();
         num_refs = refs.size();
         ref1 = refs[0];
 
         // The picture we're doing estimation from
-        m_pic_data = &(my_buffer.GetComponent( frame_num , Y_COMP));
+        m_pic_data = &(my_buffer.GetPicture( pic_num ).OrigData(Y_COMP));
 
         // Set up the hierarchy of motion vector data objects
-        m_me_data_set[0] = new MEData( m_encparams.XNumMB() , m_encparams.YNumMB() , 
-                                       m_encparams.XNumBlocks()/4 , m_encparams.YNumBlocks()/4, num_refs );
-        m_me_data_set[1] = new MEData( m_encparams.XNumMB() , m_encparams.YNumMB() , 
-                                       m_encparams.XNumBlocks()/2 , m_encparams.YNumBlocks()/2, num_refs );
+	PicturePredParams predparams0 = m_predparams;
+	predparams0.SetXNumBlocks( m_predparams.XNumBlocks()/4 );
+	predparams0.SetYNumBlocks( m_predparams.YNumBlocks()/4 );
+	
+	PicturePredParams predparams1 = m_predparams;
+	predparams1.SetXNumBlocks( m_predparams.XNumBlocks()/2 );
+	predparams1.SetYNumBlocks( m_predparams.YNumBlocks()/2 );
 
-        m_me_data_set[2] = &me_data;
+        m_me_data_set[0] = new MEData( predparams0, num_refs );
+        m_me_data_set[1] = new MEData( predparams1, num_refs );
+
+        m_me_data_set[2] = &my_buffer.GetPicture(pic_num).GetMEData();
 
         // Set up the lambdas to use per block
-        m_me_data_set[0]->SetLambdaMap( 0 , me_data.LambdaMap() , 1.0/m_level_factor[0] );
-        m_me_data_set[1]->SetLambdaMap( 1 , me_data.LambdaMap() , 1.0/m_level_factor[1] );
+        m_me_data_set[0]->SetLambdaMap( 0 , m_me_data_set[2]->LambdaMap() , 1.0/m_level_factor[0] );
+        m_me_data_set[1]->SetLambdaMap( 1 , m_me_data_set[2]->LambdaMap() , 1.0/m_level_factor[1] );
 
         // Set up the reference pictures
-        m_ref1_updata = &(my_buffer.GetUpComponent( ref1 , Y_COMP));
+        m_ref1_updata = &(my_buffer.GetPicture( ref1 ).UpOrigData(Y_COMP));
 
         if (num_refs>1)
         {
             ref2 = refs[1];
-            m_ref2_updata = &(my_buffer.GetUpComponent( ref2 , Y_COMP));
+            m_ref2_updata = &(my_buffer.GetPicture( ref2).UpOrigData(Y_COMP));
             // Create an object for computing bi-directional prediction calculations            
-
-            if ( m_encparams.MVPrecision()==MV_PRECISION_EIGHTH_PIXEL )
+            if ( m_predparams.MVPrecision()==MV_PRECISION_EIGHTH_PIXEL )
                 m_bicheckdiff = new BiBlockEighthPel( *m_ref1_updata ,
                                                       *m_ref2_updata ,
                                                       *m_pic_data );
-            else if ( m_encparams.MVPrecision()==MV_PRECISION_QUARTER_PIXEL )
+            else if ( m_predparams.MVPrecision()==MV_PRECISION_QUARTER_PIXEL )
                 m_bicheckdiff = new BiBlockQuarterPel( *m_ref1_updata ,
                                                        *m_ref2_updata ,
                                                        *m_pic_data );
@@ -150,9 +155,9 @@ void ModeDecider::DoModeDecn(const PictureBuffer& my_buffer, int frame_num, MEDa
         // Loop over all the macroblocks, doing the work //
         ///////////////////////////////////////////////////
 
-        for (m_ymb_loc=0 ; m_ymb_loc<m_encparams.YNumMB() ; ++m_ymb_loc )
+        for (m_ymb_loc=0 ; m_ymb_loc<m_predparams.YNumMB() ; ++m_ymb_loc )
         {
-            for (m_xmb_loc=0 ; m_xmb_loc<m_encparams.XNumMB(); ++m_xmb_loc )
+            for (m_xmb_loc=0 ; m_xmb_loc<m_predparams.XNumMB(); ++m_xmb_loc )
             {
                 DoMBDecn();
             }//m_xmb_loc        
@@ -162,6 +167,12 @@ void ModeDecider::DoModeDecn(const PictureBuffer& my_buffer, int frame_num, MEDa
         if (num_refs>1)
             delete m_bicheckdiff;
     }
+    
+    // Finally, although not strictly part of motion estimation,
+    // we have to assign DC values for chroma components for
+    // blocks we're decided are intra.
+    SetChromaDC( my_buffer , pic_num );
+
 }
 
 void ModeDecider::DoMBDecn()
@@ -310,8 +321,8 @@ void ModeDecider::DoME(const int xpos , const int ypos , const int level)
 
     BlockMatcher my_bmatch1( *m_pic_data , 
                              *m_ref1_updata , 
-                              m_encparams.LumaBParams(level) ,
-                              m_encparams.MVPrecision(),
+                              m_predparams.LumaBParams(level) ,
+                              m_predparams.MVPrecision(),
                               me_data.Vectors(1) , me_data.PredCosts(1) );
     me_data.PredCosts(1)[ypos][xpos].total = 100000000.0f;
     my_bmatch1.FindBestMatchSubp( xpos , ypos , cand_list, mv_pred, lambda );
@@ -342,8 +353,8 @@ void ModeDecider::DoME(const int xpos , const int ypos , const int level)
 
         BlockMatcher my_bmatch2( *m_pic_data , 
                                  *m_ref2_updata , 
-                                 m_encparams.LumaBParams(level) ,
-                                 m_encparams.MVPrecision(),
+                                 m_predparams.LumaBParams(level) ,
+                                 m_predparams.MVPrecision(),
                                  me_data.Vectors(2) , me_data.PredCosts(2) );
         me_data.PredCosts(2)[ypos][xpos].total = 100000000.0f;
         my_bmatch2.FindBestMatchSubp( xpos , ypos , cand_list, mv_pred, lambda );
@@ -374,7 +385,7 @@ float ModeDecider::DoUnitDecn(const int xpos , const int ypos , const int level
  
     BlockDiffParams dparams;
 
-    dparams.SetBlockLimits( m_encparams.LumaBParams( level ) , *m_pic_data, xpos , ypos);
+    dparams.SetBlockLimits( m_predparams.LumaBParams( level ) , *m_pic_data, xpos , ypos);
 
      // First check REF1 costs //
     /**************************/
@@ -429,7 +440,7 @@ float ModeDecider::DoUnitDecn(const int xpos , const int ypos , const int level
     // Calculate the cost if we were to code the block as intra //
     /************************************************************/
 
-    if (best_SAD_value> 4.0*m_encparams.LumaBParams( level ).Xblen()*m_encparams.LumaBParams( level ).Yblen() )
+    if (best_SAD_value> 4.0*m_predparams.LumaBParams( level ).Xblen()*m_predparams.LumaBParams( level ).Yblen() )
     {
 //        mode_cost = ModeCost( xblock , yblock ) * m_mode_factor[level];
         me_data.IntraCosts()[ypos][xpos] = m_intradiff->Diff( dparams , me_data.DC( Y_COMP )[ypos][xpos] );
@@ -438,7 +449,7 @@ float ModeDecider::DoUnitDecn(const int xpos , const int ypos , const int level
         me_data.IntraCosts()[ypos][xpos] *= m_level_factor[level];
         unit_cost = me_data.IntraCosts()[ypos][xpos] +  mode_cost;
 
-        if ( unit_cost<min_unit_cost && me_data.IntraCosts()[ypos][xpos]<0.9*best_SAD_value)
+        if ( unit_cost<min_unit_cost && me_data.IntraCosts()[ypos][xpos]<1.2*best_SAD_value)
         {
             me_data.Mode()[ypos][xpos] = INTRA;
             min_unit_cost = unit_cost;
@@ -450,7 +461,7 @@ float ModeDecider::DoUnitDecn(const int xpos , const int ypos , const int level
 
 ValueType ModeDecider::GetDCPred( int xblock , int yblock )
 {
-    ValueType dc_pred = 128;
+    ValueType dc_pred = 0;
 
     if ( xblock>0 && m_me_data_set[2]->Mode()[yblock][xblock-1] == INTRA )
     {
@@ -506,3 +517,95 @@ float ModeDecider::GetDCVar( const ValueType dc_val , const ValueType dc_pred)
 {
     return 4.0*std::abs( static_cast<float>( dc_val - dc_pred ) );
 }
+
+ValueType ModeDecider::GetChromaBlockDC(const PicArray& pic_data,
+                                            int xunit , int yunit , int split)
+{
+    BlockDiffParams dparams;
+    dparams.SetBlockLimits( m_predparams.ChromaBParams( split ) , 
+                            pic_data, xunit , yunit);
+
+    IntraBlockDiff intradiff( pic_data );
+
+    return intradiff.CalcDC( dparams );
+}
+
+void ModeDecider::SetChromaDC( const PicArray& pic_data , MEData& me_data , CompSort csort )
+{
+
+    // Lower limit of block coords in MB
+    int xtl,ytl;
+    // Upper limit of block coords in MB
+    int xbr,ybr;
+
+    // Ditto, for subMBs    
+    int xsubMBtl,ysubMBtl;
+    int xsubMBbr,ysubMBbr;
+
+    TwoDArray<ValueType>& dcarray = me_data.DC( csort );
+
+    ValueType dc = 0;
+
+    // Coords of the prediction units (at appropriate level)
+    int xunit, yunit;
+
+    // The delimiters of the blocks contained in the prediction unit
+    int xstart, ystart;
+    int xend, yend;
+
+    int level;
+
+    for ( int ymb=0 ; ymb<me_data.MBSplit().LengthY() ; ++ymb )
+    {
+        for ( int xmb=0 ; xmb<me_data.MBSplit().LengthX() ; ++xmb )
+        {
+
+            level = me_data.MBSplit()[ymb][xmb];
+
+            xtl = xmb<<2;
+            ytl = ymb<<2;            
+            xbr = xtl+4;
+            ybr = ytl+4;
+
+            xsubMBtl = xmb<<1;
+            ysubMBtl = ymb<<1;
+            xsubMBbr = xsubMBtl+2;
+            ysubMBbr = ysubMBtl+2;
+
+
+            for (int j = 0 ; j<(1<<level) ;++j)
+            {
+                 for (int i = 0 ; i<(1<<level) ;++i)
+                 {
+                     xunit = ( xmb<<level ) + i;
+                     yunit = ( ymb<<level ) + j;
+
+                     xstart = xunit<<( 2-level );
+                     ystart = yunit<<( 2-level );
+
+                     xend = xstart + ( 1<<( 2-level ) );
+                     yend = ystart + ( 1<<( 2-level ) );
+
+                     if ( me_data.Mode()[ystart][xstart] == INTRA )
+                         // Get the DC value for the unit
+                         dc = GetChromaBlockDC( pic_data , xunit , yunit , level );
+
+                     // Copy it into the corresponding blocks
+                     for ( int q=ystart ; q< yend ; ++q )
+                         for ( int p=xstart ; p< xend ; ++p )
+                             dcarray[q][p] = dc;
+
+                 }// i
+             }// j
+
+        }// xmb
+    }// ymb
+}
+
+void ModeDecider::SetChromaDC( EncQueue& my_buffer , int pic_num )
+{
+    MEData& me_data = my_buffer.GetPicture(pic_num).GetMEData();  
+    SetChromaDC( my_buffer.GetPicture( pic_num ).OrigData(U_COMP) , me_data , U_COMP );
+    SetChromaDC( my_buffer.GetPicture( pic_num ).OrigData(V_COMP) , me_data , V_COMP );
+
+}
