@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_mode_decn.h,v 1.13 2008/01/31 11:25:19 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: me_mode_decn.h,v 1.17 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -43,7 +43,7 @@
 
 namespace dirac
 {
-    class PictureBuffer;
+    class EncQueue;
 
     //! Decides between macroblock and block prediction modes.
     /*!
@@ -76,7 +76,7 @@ namespace dirac
             at splitting levels 0 and 1, as motion
             estimation must be performed for these levels.
          */
-        ModeDecider(const EncoderParams& encp );    
+        ModeDecider(const PicturePredParams& ppp );    
 
         //! Destructor
         /*!
@@ -88,10 +88,9 @@ namespace dirac
         /*!
             Does the mode decision
             \param    my_buffer    the buffer of all the relevant frames
-            \param    frame_num    the picture number for which motion estimation is being done
-            \param    me_data    the motion vector data into which decisions will be written
+            \param    pic_num    the picture number for which motion estimation is being done
          */
-        void DoModeDecn( const PictureBuffer& my_buffer , int frame_num , MEData& me_data);
+        void DoModeDecn( EncQueue& my_buffer , int pic_num );
 
     private:
         ModeDecider( const ModeDecider& cpy );//private, body-less copy constructor: this class should not be copied
@@ -119,11 +118,21 @@ namespace dirac
         //! Get a measure of DC value variance
         float GetDCVar( const ValueType dc_val , const ValueType dc_pred);
 
-         // Member data
-        PictureSort fsort;
+        //! Go through all the intra blocks and extract the chroma dc values to be coded
+        void SetChromaDC( EncQueue& my_buffer, int pic_num);
 
-        //! A local reference to the encoder params
-        const EncoderParams& m_encparams;
+        //! Called by previous fn for each component
+        void SetChromaDC(const PicArray& pic_data, MEData& me_data,CompSort csort);        
+
+        //! Called by previous fn for each block
+        ValueType GetChromaBlockDC(const PicArray& pic_data, int xloc,int yloc,int split);
+
+
+         // Member data
+        PictureSort m_psort;
+
+        //! A local reference to the picture prediction params
+        const PicturePredParams& m_predparams;
 
         //! The Lagrangian parameter for motion estimation
         float m_lambda;
