@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_subpel.cpp,v 1.15 2008/01/31 11:25:19 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: me_subpel.cpp,v 1.19 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -36,15 +36,15 @@
 * ***** END LICENSE BLOCK ***** */
 
 #include <libdirac_motionest/me_subpel.h>
-#include <libdirac_common/picture_buffer.h>
+#include <libdirac_encoder/enc_queue.h>
 using namespace dirac;
 
 #include <iostream>
 
 using std::vector;
 
-SubpelRefine::SubpelRefine(const EncoderParams& encp): 
-    m_encparams(encp),
+SubpelRefine::SubpelRefine(const PicturePredParams& ppp): 
+    m_predparams(ppp),
     m_nshift(4)
 {
     //define the relative coordinates of the four neighbours    
@@ -62,17 +62,17 @@ SubpelRefine::SubpelRefine(const EncoderParams& encp):
 
 }
 
-void SubpelRefine::DoSubpel(const PictureBuffer& my_buffer,int frame_num, MEData& me_data)
+void SubpelRefine::DoSubpel( EncQueue& my_buffer,int pic_num )
 {
     //main loop for the subpel refinement
     int ref1,ref2;
 
-    const PictureSort fsort = my_buffer.GetPicture(frame_num).GetPparams().PicSort();
+    const PictureSort psort = my_buffer.GetPicture(pic_num).GetPparams().PicSort();
 
-    if (fsort.IsInter())
+    if (psort.IsInter())
     {
         // Get the references
-        const vector<int>& refs = my_buffer.GetPicture(frame_num).GetPparams().Refs();
+        const vector<int>& refs = my_buffer.GetPicture(pic_num).GetPparams().Refs();
 
         int num_refs = refs.size();
         ref1 = refs[0];
@@ -81,9 +81,11 @@ void SubpelRefine::DoSubpel(const PictureBuffer& my_buffer,int frame_num, MEData
         else    
             ref2 = ref1;
 
-        const PicArray& pic_data = my_buffer.GetComponent(frame_num , Y_COMP);
-        const PicArray& refup1_data = my_buffer.GetUpComponent( ref1 , Y_COMP);
-        const PicArray& refup2_data = my_buffer.GetUpComponent( ref2 , Y_COMP);
+        const PicArray& pic_data = my_buffer.GetPicture(pic_num).OrigData(Y_COMP);
+        const PicArray& refup1_data = my_buffer.GetPicture(ref1).UpOrigData(Y_COMP);
+        const PicArray& refup2_data = my_buffer.GetPicture(ref2).UpOrigData(Y_COMP);
+
+	MEData& me_data = my_buffer.GetPicture(pic_num).GetMEData();
 
         // Now match the pictures
         MatchPic( pic_data , refup1_data , me_data ,1 );
@@ -108,17 +110,17 @@ void SubpelRefine::MatchPic(const PicArray& pic_data , const PicArray& refup_dat
     TwoDArray<MvCostData>& pred_costs = me_data.PredCosts( ref_id );
 
     // Provide a block matching object to do the work
-    BlockMatcher my_bmatch( pic_data , refup_data , m_encparams.LumaBParams(2) ,
-                            m_encparams.MVPrecision() , mv_array , pred_costs );
+    BlockMatcher my_bmatch( pic_data , refup_data , m_predparams.LumaBParams(2) ,
+                            m_predparams.MVPrecision() , mv_array , pred_costs );
 
     // Do the work //
     /////////////////
 
     // Loop over all the blocks, doing the work
 
-    for (int yblock=0 ; yblock<m_encparams.YNumBlocks() ; ++yblock)
+    for (int yblock=0 ; yblock<m_predparams.YNumBlocks() ; ++yblock)
     {
-        for (int xblock=0 ; xblock<m_encparams.XNumBlocks() ; ++xblock)
+        for (int xblock=0 ; xblock<m_predparams.XNumBlocks() ; ++xblock)
         {    
             DoBlock(xblock , yblock , my_bmatch , me_data , ref_id );
         }// xblock        
