@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_subpel.h,v 1.10 2008/01/31 11:25:19 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: me_subpel.h,v 1.14 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -44,7 +44,7 @@
 namespace dirac
 {
 
-    class PictureBuffer;
+    class EncQueue;
     class MvData;
     class PicArray;
     
@@ -62,9 +62,9 @@ namespace dirac
         //! Constructor
         /*!
             The constructor initialises the encoder parameters.
-            \param    cp    the parameters used for controlling encoding
+            \param    ppp   the parameters used for controlling ME/MC
          */
-        SubpelRefine(const EncoderParams& cp);
+        SubpelRefine(const PicturePredParams& ppp);
     
         //! Destructor
         ~SubpelRefine(){}
@@ -73,10 +73,9 @@ namespace dirac
         /*!
             Does the actual sub-pixel refinement.
             \param    my_buffer    the buffer of pictures being used
-            \param    frame_num    the picture number on which motion estimation is being performed
-            \param    me_data    the motion vector data, into which the results will be written
+            \param    pic_num    the picture number on which motion estimation is being performed
          */
-        void DoSubpel( const PictureBuffer& my_buffer , int frame_num , MEData& me_data );
+        void DoSubpel( EncQueue& my_buffer , int pic_num );
     
     private:
         //! Private, body-less copy constructor: this class should not be copied
@@ -99,7 +98,7 @@ namespace dirac
         //member variables
     
         //! A local reference to the encoder params
-        const EncoderParams& m_encparams;
+        const PicturePredParams& m_predparams;
     
         //! The list of candidate vectors being tested
         CandidateList m_cand_list;
