@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_utils.h,v 1.13 2008/03/14 08:17:37 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: me_utils.h,v 1.14 2008/08/14 00:58:24 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1-
 *
@@ -205,14 +205,17 @@ namespace dirac
         */
         IntraBlockDiff( const PicArray& pic );
 
-        //! Do the difference, returning SAD
+        //! Do the difference, calculating the DC value and returning SAD
         /*!
-            Do the difference, returning SAD
+            Do the difference, calculating the DC value and returning SAD
             \param    dparams    block parameters
             \param    dc_val     DC value
         */        
         float Diff( const BlockDiffParams& dparams , ValueType& dc_val );
 
+        //! Calculate a DC value
+	ValueType CalcDC( const BlockDiffParams& dparams);
+
     private:
         //! Private, bodyless copy-constructor: class should not be copied
         IntraBlockDiff(const IntraBlockDiff& cpy);
