@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: pixel_match.cpp,v 1.14 2008/05/27 01:29:55 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: pixel_match.cpp,v 1.19 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -39,7 +39,7 @@
 #include <libdirac_motionest/pixel_match.h>
 #include <libdirac_motionest/block_match.h>
 #include <libdirac_common/motion.h>
-#include <libdirac_common/picture_buffer.h>
+#include <libdirac_encoder/enc_queue.h>
 #include <libdirac_motionest/downconvert.h>
 #include <libdirac_motionest/me_mode_decn.h>
 #include <libdirac_motionest/me_subpel.h>
@@ -56,8 +56,9 @@ PixelMatcher::PixelMatcher( const EncoderParams& encp):
 {}
 
 
-void PixelMatcher::DoSearch(const PictureBuffer& my_buffer, int frame_num, MEData& me_data)
+void PixelMatcher::DoSearch( EncQueue& my_buffer, int pic_num )
 {
+    m_predparams = &(my_buffer.GetPicture(pic_num).GetMEData().GetPicPredParams() );
 
      //does an initial search using hierarchical matching to get guide vectors    
 
@@ -65,9 +66,9 @@ void PixelMatcher::DoSearch(const PictureBuffer& my_buffer, int frame_num, MEDat
     int ref1,ref2;
 
     // Use the luminance only for motion estimating
-    const PicArray& pic_data = my_buffer.GetComponent( frame_num , Y_COMP );
+    const PicArray& pic_data = my_buffer.GetPicture( pic_num ).DataForME(m_encparams.FieldCoding(), Y_COMP);
 
-    const vector<int>& refs = my_buffer.GetPicture( frame_num ).GetPparams().Refs();
+    const vector<int>& refs = my_buffer.GetPicture( pic_num ).GetPparams().Refs();
     ref1 = refs[0];
 
     if (refs.size()>1)
@@ -76,15 +77,15 @@ void PixelMatcher::DoSearch(const PictureBuffer& my_buffer, int frame_num, MEDat
         ref2 = ref1;
 
     // Record temporal distances
-    m_tdiff[0] = std::abs( ref1 - frame_num );
-    m_tdiff[1] = std::abs( ref2 - frame_num );
+    m_tdiff[0] = std::abs( ref1 - pic_num );
+    m_tdiff[1] = std::abs( ref2 - pic_num );
 
     // Obtain C++ references to the reference picture luma components
-    const PicArray& ref1_data = my_buffer.GetComponent(ref1 , Y_COMP);
-    const PicArray& ref2_data = my_buffer.GetComponent(ref2 , Y_COMP);
-
+    const PicArray& ref1_data = my_buffer.GetPicture(ref1).DataForME(m_encparams.FieldCoding(), Y_COMP);
+    const PicArray& ref2_data = my_buffer.GetPicture(ref2).DataForME(m_encparams.FieldCoding(), Y_COMP);
+ 
     // Determine the picture sort - this affects the motion estimation Lagrangian parameter
-    m_fsort = my_buffer.GetPicture(frame_num).GetPparams().PicSort();
+    m_psort = my_buffer.GetPicture(pic_num).GetPparams().PicSort();
 
 
     if ( m_encparams.FullSearch() == false )
@@ -131,6 +132,7 @@ void PixelMatcher::DoSearch(const PictureBuffer& my_buffer, int frame_num, MEDat
 
         // Finally, do the top level, with the pictures themselves
         m_level = 0;
+	MEData& me_data = my_buffer.GetPicture(pic_num).GetMEData();
         MatchPic( pic_data , ref1_data, me_data , *(me_data_set[1]) , 1 );
         if ( ref1 != ref2 )
             MatchPic( pic_data , ref2_data , me_data , *(me_data_set[1]) , 2 );
@@ -146,6 +148,7 @@ void PixelMatcher::DoSearch(const PictureBuffer& my_buffer, int frame_num, MEDat
     {
         m_depth = 0;
         m_level = 0;
+	MEData& me_data = my_buffer.GetPicture(pic_num).GetMEData();
         MatchPic( pic_data , ref1_data, me_data , me_data , 1 );
         if ( ref1 != ref2 )
             MatchPic( pic_data , ref2_data , me_data , me_data , 2 );
@@ -184,14 +187,18 @@ void PixelMatcher::MakeMEDataHierarchy(const OneDArray< PicArray*>& down_data,
 {
 
     int xnumblocks , ynumblocks;
-    const OLBParams bparams = m_encparams.LumaBParams(2);
+    const OLBParams bparams = m_predparams->LumaBParams(2);
 
     // We might not have an integral number of Macroblocks and blocks in 
     // a picture. So we go start of with the number of macroblocks in the
     // full size picture and calculate the number of in the downsized pics
     // from this.
-    xnumblocks = m_encparams.XNumBlocks();
-    ynumblocks = m_encparams.YNumBlocks();
+    xnumblocks = m_predparams->XNumBlocks();
+    ynumblocks = m_predparams->YNumBlocks();
+
+    PicturePredParams predparams = *m_predparams;
+    predparams.SetXNumMB(0);
+    predparams.SetYNumMB(0);
     for (int i=1 ; i<=m_depth;++i)
     {
 
@@ -204,7 +211,10 @@ void PixelMatcher::MakeMEDataHierarchy(const OneDArray< PicArray*>& down_data,
         if (( down_data[i]->LengthY() )%bparams.Ybsep() != 0)
             ynumblocks++;
 
-        me_data_set[i] = new MEData( 0 , 0 , xnumblocks , ynumblocks, 2 );
+	predparams.SetXNumBlocks( xnumblocks );
+	predparams.SetYNumBlocks( ynumblocks );
+
+        me_data_set[i] = new MEData( predparams, 2 );
     }// i
 
 }
@@ -273,7 +283,7 @@ void PixelMatcher::MatchPic(const PicArray& pic_data , const PicArray& ref_data
 
     // Provide a block matching object to do the work
     BlockMatcher my_bmatch( pic_data , ref_data , 
-                            m_encparams.LumaBParams(2) , m_encparams.MVPrecision() ,
+                            m_predparams->LumaBParams(2) , m_predparams->MVPrecision() ,
                             mv_array , pred_costs );
 
     // Do the work - loop over all the blocks, finding the best match //
