@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion_comp_test.cpp,v 1.15 2008/04/29 12:26:44 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: motion_comp_test.cpp,v 1.17 2008/08/27 01:06:05 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -69,9 +69,9 @@ void MotionCompTest::tearDown()
 }
 
 
-MvData* setupMV1Data(CodecParams& cp, int mv_x, int mv_y, PredMode mode)
+MvData* setupMV1Data(const PicturePredParams& ppp, int mv_x, int mv_y, PredMode mode)
 {
-    MvData* mv_data = new MvData(cp.XNumMB(),cp.YNumMB(),cp.XNumBlocks(),cp.YNumBlocks(), 2);
+    MvData* mv_data = new MvData(ppp, 2);
     MvArray& arr = mv_data->Vectors(1);
     for (int i =arr.FirstY(); i <= arr.LastY(); i++)
     {
@@ -108,22 +108,23 @@ void MotionCompTest::testZeroMotionComp()
 
 void MotionCompTest::testZeroMotionComp(MVPrecisionType precision)
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 1, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
 
-    cp.SetMVPrecision(precision);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetMVPrecision(precision);
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
 
     // MotionCompensator mc( cp );
     
-    MvData* mv_data = setupMV1Data(cp, 0, 0, REF1_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 0, 0, REF1_ONLY);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
 
@@ -142,15 +143,17 @@ void MotionCompTest::testZeroMotionComp(MVPrecisionType precision)
     pbuffer.PushPicture(pp);
     PicturesTest::zeroPicture(pbuffer.GetPicture(2));
 
+    Picture* ref_pics[2] = { &pbuffer.GetPicture(1), &pbuffer.GetPicture(2) };
+
     // mc.CompensatePicture(ADD, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     // MotionCompensator mc2( cp );
 
     //too many rounding errors for this to be exactly true;
     //CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(0), pbuffer.GetPicture(1)));
     // mc2.CompensatePicture(SUBTRACT, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, SUBTRACT, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, SUBTRACT, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(2), pbuffer.GetPicture(1)));
     delete mv_data;
@@ -166,19 +169,20 @@ void MotionCompTest::testAddandSubMotionComp()
 
 void MotionCompTest::testAddandSubMotionComp(MVPrecisionType precision)
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 1, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
-    cp.SetMVPrecision(precision);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetMVPrecision(precision);
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
 
     
-    MvData* mv_data = setupMV1Data(cp, 5, 5, REF1_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 5, 5, REF1_ONLY);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
 
@@ -197,13 +201,15 @@ void MotionCompTest::testAddandSubMotionComp(MVPrecisionType precision)
     pbuffer.PushPicture(pp);
     PicturesTest::zeroPicture(pbuffer.GetPicture(2));
 
+    Picture* ref_pics[2] = { &pbuffer.GetPicture(1), &pbuffer.GetPicture(2) };
+
     // MotionCompensator mc( cp );
     // mc.CompensatePicture(ADD, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     // MotionCompensator mc2( cp );
     // mc2.CompensatePicture(SUBTRACT, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, SUBTRACT, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, SUBTRACT, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(2), pbuffer.GetPicture(1)));
     delete mv_data;
@@ -219,19 +225,20 @@ void MotionCompTest::testL2_picture()
 
 void MotionCompTest::testL2_picture(MVPrecisionType precision)
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 1, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
-    cp.SetMVPrecision(precision);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetMVPrecision(precision);
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
 
     
-    MvData* mv_data = setupMV1Data(cp, 5, 5, REF1_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 5, 5, REF1_ONLY);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
 
@@ -250,13 +257,15 @@ void MotionCompTest::testL2_picture(MVPrecisionType precision)
     pbuffer.PushPicture(pp);
     PicturesTest::zeroPicture(pbuffer.GetPicture(2));
 
+    Picture* ref_pics[2] = { &pbuffer.GetPicture(1), &pbuffer.GetPicture(2) };
+
     // MotionCompensator mc( cp );
     // mc.CompensatePicture(ADD, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     // MotionCompensator mc2( cp );
     // mc2.CompensatePicture(SUBTRACT, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, SUBTRACT, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, SUBTRACT, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(2), pbuffer.GetPicture(1)));
     delete mv_data;
@@ -265,19 +274,20 @@ void MotionCompTest::testL2_picture(MVPrecisionType precision)
 
 void MotionCompTest::testI_picture()
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 2, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
 
 
     
-    MvData* mv_data = setupMV1Data(cp, 5, 5, REF1_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 5, 5, REF1_ONLY);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
 
@@ -292,10 +302,11 @@ void MotionCompTest::testI_picture()
     pbuffer.PushPicture(pp);
     PicturesTest::setupPicture(pbuffer.GetPicture(1),0);
 
+    Picture* ref_pics[2] = { &pbuffer.GetPicture(1), &pbuffer.GetPicture(1) };
 
     // MotionCompensator mc( cp );
     // mc.CompensatePicture(ADD, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(0), pbuffer.GetPicture(1)));
     delete mv_data;
@@ -312,20 +323,21 @@ void MotionCompTest::testRef2()
 
 void MotionCompTest::testRef2(MVPrecisionType precision)
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 2, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
-    cp.SetMVPrecision(precision);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetMVPrecision(precision);
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
 
 
     
-    MvData* mv_data = setupMV1Data(cp, 5, 5, REF2_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 5, 5, REF2_ONLY);
     setupMV2Data(mv_data, 0, 0);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
@@ -346,16 +358,18 @@ void MotionCompTest::testRef2(MVPrecisionType precision)
     pbuffer.PushPicture(pp);
     PicturesTest::zeroPicture(pbuffer.GetPicture(2));
 
+    Picture* ref_pics[2] = { &pbuffer.GetPicture(1), &pbuffer.GetPicture(2) };
+
     // MotionCompensator mc( cp );
     // mc.CompensatePicture(ADD, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     //too many rounding errors for this to be exactly true;
     //CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(0), pbuffer.GetPicture(1)));
 
     // MotionCompensator mc2( cp );
     // mc2.CompensatePicture(SUBTRACT, pbuffer, 1, *mv_data);
-    MotionCompensator::CompensatePicture(cp, SUBTRACT, pbuffer, 1, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, SUBTRACT, *mv_data, &pbuffer.GetPicture(0), ref_pics );
 
     CPPUNIT_ASSERT (PicturesTest::equalPictures (pbuffer.GetPicture(2), pbuffer.GetPicture(1)));
     delete mv_data;
@@ -371,24 +385,25 @@ void MotionCompTest::testRef1and2()
 
 void MotionCompTest::testRef1and2(MVPrecisionType precision)
 {
-    PictureBuffer pbuffer(format420, X_SIZE, Y_SIZE, 8, 8, true);
+    PictureBuffer pbuffer;
     CodecParams cp(VIDEO_FORMAT_CIF, INTER_PICTURE, 2, true);
+    PicturePredParams &ppp = cp.GetPicPredParams();
     OLBParams bparams(12, 12, 8, 8);
-    cp.SetMVPrecision(precision);
-    cp.SetBlockSizes(bparams, pbuffer.GetPictureParams().CFormat());
-    cp.SetXNumMB( X_SIZE / cp.LumaBParams(0).Xbsep() );
-    cp.SetYNumMB( Y_SIZE / cp.LumaBParams(0).Ybsep() );
+    ppp.SetMVPrecision(precision);
+    ppp.SetBlockSizes(bparams, format420 );
+    ppp.SetXNumMB( X_SIZE / ppp.LumaBParams(0).Xbsep() );
+    ppp.SetYNumMB( Y_SIZE / ppp.LumaBParams(0).Ybsep() );
 
-    cp.SetXNumBlocks( 4*cp.XNumMB() );
-    cp.SetYNumBlocks( 4*cp.YNumMB() );
+    ppp.SetXNumBlocks( 4*ppp.XNumMB() );
+    ppp.SetYNumBlocks( 4*ppp.YNumMB() );
     
-    MvData* mv_data = setupMV1Data(cp, 5, 5, REF1_ONLY);
+    MvData* mv_data = setupMV1Data(ppp, 5, 5, REF1_ONLY);
     setupMV2Data(mv_data, 5, 5);
 
-    MvData* mv_data1 = setupMV1Data(cp, 7, 3, REF2_ONLY);
+    MvData* mv_data1 = setupMV1Data(ppp, 7, 3, REF2_ONLY);
     setupMV2Data(mv_data1, 7, 3);
 
-    MvData* mv_data2 = setupMV1Data(cp, 5, 5, REF1AND2);
+    MvData* mv_data2 = setupMV1Data(ppp, 5, 5, REF1AND2);
     setupMV2Data(mv_data2, 7, 3);
 
     PictureParams pp(format420, X_SIZE, Y_SIZE, 8, 8);
@@ -415,24 +430,28 @@ void MotionCompTest::testRef1and2(MVPrecisionType precision)
     PicturesTest::zeroPicture(pbuffer.GetPicture(3));
 
     //MotionCompensator mc( cp );
+    
+    Picture* ref_pics[2];
+    ref_pics[0] = &pbuffer.GetPicture(0);
+    ref_pics[1] = &pbuffer.GetPicture(1);
 
     //mc.CompensatePicture(ADD, pbuffer, 2, *mv_data);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 2, *mv_data);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data, &pbuffer.GetPicture(2), ref_pics);
 
     //MotionCompensator mc2( cp );
 
     //mc2.CompensatePicture(ADD, pbuffer, 2, *mv_data1);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 2, *mv_data1);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data1, &pbuffer.GetPicture(2), ref_pics);
 
     // MotionCompensator mc3( cp );
 
     // mc3.CompensatePicture(ADD, pbuffer, 3, *mv_data2);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 3, *mv_data2);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data2, &pbuffer.GetPicture(3), ref_pics);
 
     //MotionCompensator mc4( cp );
 
     //mc4.CompensatePicture(ADD, pbuffer, 3, *mv_data2);
-    MotionCompensator::CompensatePicture(cp, ADD, pbuffer, 3, *mv_data2);
+    MotionCompensator::CompensatePicture(ppp, ADD, *mv_data2, &pbuffer.GetPicture(3), ref_pics);
 
     CPPUNIT_ASSERT (PicturesTest::almostEqualPictures (pbuffer.GetPicture(2), pbuffer.GetPicture(3), 5    ));
     delete mv_data;
