@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion_arrows.cpp,v 1.7 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: motion_arrows.cpp,v 1.8 2008/06/19 10:39:59 tjdwave Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -37,6 +37,7 @@
 
 #include <util/instrumentation/libdirac_instrument/motion_arrows.h>
 using namespace dirac_instr;
+using namespace dirac;
 
 // constructor
 DrawMotionArrows::DrawMotionArrows(Picture & picture, DrawPictureMotionParams & draw_params,
@@ -59,14 +60,14 @@ void DrawMotionArrows::DrawBlock(int j, int i)
     // no chroma in picture
     for (int y=j*m_draw_params.MvUVBlockY(); y<(j+1)*m_draw_params.MvUVBlockY(); ++y)
     {
-        if (y >= m_picture.Udata().LengthY() || y >= m_picture.Vdata().LengthY())
+        if (y >= m_picture.Data(U_COMP).LengthY() || y >= m_picture.Data(V_COMP).LengthY())
             break;
         for (int x=i*m_draw_params.MvUVBlockX(); x<(i+1)*m_draw_params.MvUVBlockX(); ++x)
         {
-            if (x >= m_picture.Udata().LengthX() || x >= m_picture.Vdata().LengthX())
+            if (x >= m_picture.Data(U_COMP).LengthX() || x >= m_picture.Data(V_COMP).LengthX())
                 break;
-            m_picture.Udata()[y][x] = 0;
-            m_picture.Vdata()[y][x] = 0;
+            m_picture.Data(U_COMP)[y][x] = 0;
+            m_picture.Data(V_COMP)[y][x] = 0;
         }
     }
 
@@ -100,8 +101,8 @@ void DrawMotionArrows::DrawBlock(int j, int i)
 
     // draw arrow if this block is TL corner of arrow
     if ( (j == 0 || (j % m_blocks_per_arrow_y) == 0) && ((i == 0 || (i % m_blocks_per_arrow_x) == 0 )) &&
-        (j*m_draw_params.MvYBlockY()+offset_y+15 <= m_picture.Ydata().LengthY()) &&
-        (i*m_draw_params.MvYBlockX()+offset_x+15 <= m_picture.Ydata().LengthX()) )
+        (j*m_draw_params.MvYBlockY()+offset_y+15 <= m_picture.Data(Y_COMP).LengthY()) &&
+        (i*m_draw_params.MvYBlockX()+offset_x+15 <= m_picture.Data(Y_COMP).LengthX()) )
     {
         DrawArrow(j, i, (j*m_draw_params.MvYBlockY())+offset_y, (i*m_draw_params.MvYBlockX())+offset_x);
     }
@@ -196,7 +197,7 @@ void DrawMotionArrows::DrawArrow(int j, int i, int y_pos, int x_pos)
         {
             for (int xpx=0; xpx<16; ++xpx)
             {
-                m_picture.Ydata()[(y_pos)+ypx][(x_pos) + xpx] += m_symbols.Arrow()[ypx][15-xpx] * 256;
+                m_picture.Data(Y_COMP)[(y_pos)+ypx][(x_pos) + xpx] += m_symbols.Arrow()[ypx][15-xpx] * 256;
             }// xpx
         }// ypx
     }
@@ -206,7 +207,7 @@ void DrawMotionArrows::DrawArrow(int j, int i, int y_pos, int x_pos)
         {
             for (int xpx=0; xpx<16; ++xpx)
             {
-                m_picture.Ydata()[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[15-ypx][xpx] * 256;
+                m_picture.Data(Y_COMP)[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[15-ypx][xpx] * 256;
             }// xpx
         }// ypx
     }
@@ -216,7 +217,7 @@ void DrawMotionArrows::DrawArrow(int j, int i, int y_pos, int x_pos)
         {
             for (int xpx=0; xpx<16; ++xpx)
             {
-                m_picture.Ydata()[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[15-ypx][15-xpx] * 256;
+                m_picture.Data(Y_COMP)[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[15-ypx][15-xpx] * 256;
             }// xpx
         }// ypx
     }
@@ -226,7 +227,7 @@ void DrawMotionArrows::DrawArrow(int j, int i, int y_pos, int x_pos)
         {
             for (int xpx=0; xpx<16; ++xpx)
             {
-                m_picture.Ydata()[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[ypx][xpx] * 256;
+                m_picture.Data(Y_COMP)[(y_pos) + ypx][(x_pos) + xpx] += m_symbols.Arrow()[ypx][xpx] * 256;
             }// xpx
         }// ypx
     }
