@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: sad.cpp,v 1.7 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: sad.cpp,v 1.8 2008/06/19 10:39:59 tjdwave Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -37,6 +37,7 @@
 
 #include <util/instrumentation/libdirac_instrument/sad.h>
 using namespace dirac_instr;
+using namespace dirac;
 
 // constructor
 DrawSad::DrawSad(Picture & picture, DrawPictureMotionParams & draw_params, const TwoDArray<MvCostData> & cost, const TwoDArray<PredMode> & mode, 
@@ -68,20 +69,20 @@ void DrawSad::DrawBlock(int j, int i)
         int xidx = (i*m_draw_params.MvYBlockX());
         for (int ypx=0; ypx<m_draw_params.MvYBlockY(); ++ypx)
         {
-            if ((yidx+ypx)>=m_picture.Ydata().LengthY() ||
-                (xidx+m_draw_params.MvYBlockX()-1)>= m_picture.Ydata().LengthX())
+            if ((yidx+ypx)>=m_picture.Data(Y_COMP).LengthY() ||
+                (xidx+m_draw_params.MvYBlockX()-1)>= m_picture.Data(Y_COMP).LengthX())
                 break;
-            m_picture.Ydata()[(j*m_draw_params.MvYBlockY())+ypx][(i*m_draw_params.MvYBlockX())] = 250;
-            m_picture.Ydata()[(j*m_draw_params.MvYBlockY())+ypx][(i*m_draw_params.MvYBlockX())+m_draw_params.MvYBlockX()-1] = 250;
+            m_picture.Data(Y_COMP)[(j*m_draw_params.MvYBlockY())+ypx][(i*m_draw_params.MvYBlockX())] = 250;
+            m_picture.Data(Y_COMP)[(j*m_draw_params.MvYBlockY())+ypx][(i*m_draw_params.MvYBlockX())+m_draw_params.MvYBlockX()-1] = 250;
         }// ypx
 
         for (int xpx=0; xpx<m_draw_params.MvYBlockX(); ++xpx)
         {
-            if ((yidx+m_draw_params.MvYBlockY()-1)>=m_picture.Ydata().LengthY() ||
-                (xidx+xpx)>= m_picture.Ydata().LengthX())
+            if ((yidx+m_draw_params.MvYBlockY()-1)>=m_picture.Data(Y_COMP).LengthY() ||
+                (xidx+xpx)>= m_picture.Data(Y_COMP).LengthX())
                 break;
-            m_picture.Ydata()[(j*m_draw_params.MvYBlockY())][(i*m_draw_params.MvYBlockX())+xpx] = 250;
-            m_picture.Ydata()[(j*m_draw_params.MvYBlockY())+m_draw_params.MvYBlockY()-1][(i*m_draw_params.MvYBlockX())+xpx] = 250;
+            m_picture.Data(Y_COMP)[(j*m_draw_params.MvYBlockY())][(i*m_draw_params.MvYBlockX())+xpx] = 250;
+            m_picture.Data(Y_COMP)[(j*m_draw_params.MvYBlockY())+m_draw_params.MvYBlockY()-1][(i*m_draw_params.MvYBlockX())+xpx] = 250;
         }// xpx
     }
 }
