@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: split_mode.cpp,v 1.7 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
+* $Id: split_mode.cpp,v 1.8 2008/06/19 10:39:59 tjdwave Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -37,6 +37,7 @@
 
 #include <util/instrumentation/libdirac_instrument/split_mode.h>
 using namespace dirac_instr;
+using namespace dirac;
 
 // constructor
 DrawSplitMode::DrawSplitMode(Picture & picture, DrawPictureMotionParams & draw_params, const TwoDArray<int> & mode)
@@ -73,7 +74,7 @@ void DrawSplitMode::DrawLegend()
     for (int ypx=m_draw_params.PicY()-49; ypx<m_draw_params.PicY(); ++ypx)
     {
         for (int xpx=7; xpx>=0; --xpx)
-            m_picture.Ydata()[ypx][xpx]=0; // grey
+            m_picture.Data(Y_COMP)[ypx][xpx]=0; // grey
     }
 
     int U=0, V=0;
@@ -93,9 +94,9 @@ void DrawSplitMode::DrawLegend()
     // black horizontal lines
     for (int xpx=15; xpx>=0; --xpx)
     {
-        m_picture.Ydata()[m_draw_params.PicY()-49][xpx]=-128;
-        m_picture.Ydata()[m_draw_params.PicY()-33][xpx]=-128;
-        m_picture.Ydata()[m_draw_params.PicY()-17][xpx]=-128;
+        m_picture.Data(Y_COMP)[m_draw_params.PicY()-49][xpx]=-128;
+        m_picture.Data(Y_COMP)[m_draw_params.PicY()-33][xpx]=-128;
+        m_picture.Data(Y_COMP)[m_draw_params.PicY()-17][xpx]=-128;
     }
 
     // draw '2 1 0' label
