@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: process_sequence.cpp,v 1.15 2008/05/02 05:49:35 asuraparaju Exp $ $Name: Dirac_0_10_0 $
+* $Id: process_sequence.cpp,v 1.16 2008/08/27 00:18:56 asuraparaju Exp $ $Name: Dirac_1_0_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -184,8 +184,14 @@ void ProcessSequence::AddPictureEntry()
         m_data_in >> mv_ynum; // motion vector array dimensions
         m_data_in >> mv_xnum;
 
+        PicturePredParams predparams;
+	predparams.SetXNumBlocks(mv_xnum);
+	predparams.SetYNumBlocks(mv_ynum);
+	predparams.SetXNumMB(mb_xnum);
+	predparams.SetYNumMB(mb_ynum);
+
         // create motion data object
-        m_data_array[new_index].me_data = new MEData(mb_xnum, mb_ynum, mv_xnum, mv_ynum , total_refs );
+        m_data_array[new_index].me_data = new MEData(predparams , total_refs );
         if (m_verbose)
             std::cout << std::endl << "Allocating " << new_index << " MEData object";
 
